(function () {
  "use strict";

  var WIDTH_CONTENT_S = 520;
  var WIDTH_CONTENT_M = 930;
  /**
   * 增值税主表绘制信息
   */
  var MAIN_TABLE_COLUMN_NAMES = [
    {
      cols: [{rowspan: 15, value: "一<br /><br />计<br />税<br />依<br />据"}],
      columnName: "（一）应征增值税不含税销售额（3%征收率）",
      index: 1,
      name: "yzBhsXse",
      bys: {type: "float2"},
      bysFw: {type: "float2"}
    }, // 1
    {
      columnName: "　　税务机关代开的增值税专用发票不含税销售额",
      index: 2,
      name: "yzSwdkZyfpBhsXse",
      bys: {type: "float2"},
      bysFw: {type: "float2"}
    }, // 2
    {
      columnName: "　　税控器具开具的普通发票不含税销售额",
      index: 3,
      name: "yzSkPtfpBhsXse",
      bys: {type: "float2"},
      bysFw: {type: "float2"}
    }, // 3
    {
      columnName: "（二）应征增值税不含税销售额（5%征收率）",
      index: 4,
      name: "yzBhsXse5",
      bys: {disabled: true, type: "float2"},
      bysFw: {type: "float2"}
    }, // 4
    {
      columnName: "　　　税务机关代开的增值税专用发票不含税销售额",
      index: 5,
      name: "yzSwdkZyfpBhsXse5",
      bys: {disabled: true, type: "float2"},
      bysFw: {type: "float2"}
    }, // 5
    {
      columnName: "　　　税控器具开具的普通发票不含税销售额",
      index: 6,
      name: "yzSkPtfpBhsXse5",
      bys: {disabled: true, type: "float2"},
      bysFw: {type: "float2"}
    }, // 6
    {
      columnName: "（三）销售使用过的固定资产不含税销售额",
      index: 7,
      name: "ysgzBhsXse",
      bys: {type: "float2"},
      bysFw: {disabled: true, type: "float2"}
    }, // 7
    {
      columnName: "其中：税控器具开具的普通发票不含税销售额",
      index: 8,
      name: "ysgzSkPtfpBhsXse",
      bys: {type: "float2"},
      bysFw: {disabled: true, type: "float2"}
    }, // 8
    {
      columnName: "（四）免税销售额",
      index: 9,
      name: "msXse",
      bys: {readonly: true, type: "float2"},
      bysFw: {readonly: true, type: "float2"}
    }, // 9
    {
      columnName: "其中：小微企业免税销售额",
      index: 10,
      name: "msXwqyXse",
      bys: {disabled: true, type: "float2"},
      bysFw: {disabled: true, type: "float2"}
    }, // 10
    {columnName: "　　　未达起征点销售额", index: 11, name: "msWdqzdXse", bys: {type: "float2"}, bysFw: {type: "float2"}}, // 11
    {columnName: "　　　其他免税销售额", index: 12, name: "msQtXse", bys: {type: "float2"}, bysFw: {type: "float2"}}, // 12
    {columnName: "（五）出口免税销售额", index: 13, name: "ckmsXse", bys: {type: "float2"}, bysFw: {type: "float2"}}, // 13
    {
      columnName: "其中：税控器具开具的普通发票销售额",
      index: 14,
      name: "ckmsSkPtfpXse",
      bys: {type: "float2"},
      bysFw: {type: "float2"}
    }, // 14
    {
      columnName: "核定销售额",
      index: 15,
      name: "hdxse",
      bys: {readonly: true, type: "float2"},
      bysFw: {readonly: true, type: "float2"}
    }, // 15
    {
      cols: [{rowspan: 9, value: "二<br /><br />税<br />款<br />计<br />算"}],
      columnName: "本期应纳税额",
      index: 16,
      name: "ynSeBq",
      bys: {type: "float2"},
      bysFw: {type: "float2"}
    }, // 16
    {
      columnName: "核定应纳税额",
      index: 17,
      name: "hdynse",
      bys: {readonly: true, type: "float2"},
      bysFw: {readonly: true, type: "float2"}
    }, // 17
    {columnName: "本期应纳税额减征额", index: 18, name: "ynSeJzeBq", bys: {type: "float2"}, bysFw: {type: "float2"}}, // 18
    {columnName: "本期免税额", index: 19, name: "mseBq", bys: {type: "float2"}, bysFw: {type: "float2"}}, // 19
    {
      columnName: "其中：小微企业免税额",
      index: 20,
      name: "xwqyMseBq",
      bys: {disabled: true, type: "float2"},
      bysFw: {disabled: true, type: "float2"}
    }, // 20
    {columnName: "　　　未达起征点免税额", index: 21, name: "wdqzdMseBq", bys: {type: "float2"}, bysFw: {type: "float2"}}, // 21
    {
      columnName: "应纳税额合计",
      index: 22,
      name: "ynSeHj",
      bys: {readonly: true, type: "float2"},
      bysFw: {readonly: true, type: "float2"}
    }, // 22
    {columnName: "本期预缴税额", index: 23, name: "yjSeBq", bys: {type: "float2"}, bysFw: {type: "float2"}}, // 23
    {
      columnName: "本期应补（退）税额",
      index: 24,
      name: "ybtSeBq",
      bys: {readonly: true, type: "float2"},
      bysFw: {readonly: true, type: "float2"}
    } // 24
  ];

  /**
   * 纳税人基本信息
   */
  var DEFAULT_NSR_INFO = {
    "returnCode": "00",     // 返回码
    "returnMessage": "",    // 返回信息
    "serverTime": "",       // 系统当前时间
    "nsrsbh": "",           // 纳税人识别号
    "nsrmc": "",            // 纳税人名称
    "ishh": false,          // 合伙企业
    "zzs": {
      "zsxmDm": "",           // 征收项目代码
      "zsxmMc": "",           // 征收项目名称
      "nsqxDm": "",           // 纳税期限代码
      "nsqxMc": "",           // 纳税期限名称
      "sbqx": "",             // 申报期限
      "vjkqx": "",            // 缴款期限
      "sssqQ": "",            // 所属属期起
      "sssqZ": "",            // 所属属期止
      "yqsbBz": "N",          // 逾期申报标志
      "ysbBz": "N",           // 已申报标志
      "yjkBz": "N",           // 已缴款标志
      "yqwrdybrBz": "N",      // 逾期未认定一般人标志
      "dqdeBz": "N",          // 定期定额标志（征收方式）
      "jcxxBz": "Y",          // 基础信息标志
      "sfXgm": "Y",           // 是否为小规模
      "yshwYjs": 0,           // 应税货物预缴数
      "ysfwYjs": 0,           // 服务、不动产和无形资产预缴数
      "szlbDm": "03",         // 税种类别代码(01:单货物，02:单服务，03:货物、服务都有)
      "szlbMc": "混征增值税",  // 税种类别名称
      "jmzg": "N",            // 减免资格
      "qzd": 0,               // 起征点
      "fwqzd": 0,             // 服务起征点
      "ydkzyfpje": 0,         // 已代开专用发票金额
      "qcye": 0,              // 附表四期初余额
      "bqfse": 0,             // 附表四本期发生额
      "hdxseHw": 0,           // 应税货物核定销售额
      "hdxseFw": 0,           // 服务、不动产和无形资产核定销售额
      "hdynseHw": 0,          // 应税货物核定应纳税额
      "hdynseFw": 0,          // 服务、不动产和无形资产核定应纳税额

      "xgmLjs": 0,            // 小规模累计数，即往期销售额相加
      "xgmXseHw": 0,          // 小规模销售额(货物)，即增值税当期销售额（增值税未申报时为0），单独申报附加税时判断是否免征
      "xgmXseFw": 0,          // 小规模销售额(服务)，即增值税当期销售额（增值税未申报时为0），单独申报附加税时判断是否免征
      "xgmYbtse": 0,          // 附加税累计数，即增值税当期应补退税额（增值税未申报时为0），单独申报附加税时作为计税依据（一般增值税）

      "gsyjs": 0,             // 个税预缴数
      "zzsGzbz": "N"          // 增值税更正标志
    },
    "gzbz": "N"                 // 更正标志
  };

  /**
   * 默认的申报数据
   */
  var DEFAULT_GRID_VALUES = {
    "isAndroid": true,          // 平台是否是安卓
    "isJysb": false,            // 是否是简易申报进入的
    "bys": {
      "yzBhsXse": 0,          // （一）应征增值税不含税销售额（3%征收率）  1
      "yzSwdkZyfpBhsXse": 0,  // 税务机关代开的增值税专用发票不含税销售额  2
      "yzSkPtfpBhsXse": 0,    // 税控器具开具的普通发票不含税销售额  3
      "yzBhsXse5": 0,         // （二）应征增值税不含税销售额（5%征收率）  4
      "yzSwdkZyfpBhsXse5": 0, // 税务机关代开的增值税专用发票不含税销售额  5
      "yzSkPtfpBhsXse5": 0,   // 税控器具开具的普通发票不含税销售额  6
      "ysgzBhsXse": 0,        // （三）销售使用过的应税固定资产不含税销售额  7
      "ysgzSkPtfpBhsXse": 0,  // 其中：税控器具开具的普通发票不含税销售额  8
      "msXse": 0,             // （四）免税销售额  9
      "msXwqyXse": 0,         // 其中：小微企业免税销售额  10
      "msWdqzdXse": 0,        // 未达起征点销售额  11
      "msQtXse": 0,           // 其他免税销售额  12
      "ckmsXse": 0,           // （五）出口免税销售额  13
      "ckmsSkPtfpXse": 0,     // 其中：税控器具开具的普通发票销售额  14
      "hdxse": 0,             // 核定销售额  15
      "ynSeBq": 0,            // 本期应纳税额  16
      "hdynse": 0,            // 核定应纳税额 17
      "ynSeJzeBq": 0,         // 本期应纳税额减征额  18
      "mseBq": 0,             // 本期免税额  19
      "xwqyMseBq": 0,         // 其中：小微企业免税额  20
      "wdqzdMseBq": 0,        // 未达起征点免税额  21
      "ynSeHj": 0,            // 应纳税额合计  22
      "yjSeBq": 0,            // 本期预缴税额  23
      "ybtSeBq": 0            // 本期应补（退）税额  24
    },
    "bysFw": {
      "yzBhsXse": 0,          // （一）应征增值税不含税销售额（3%征收率）  1
      "yzSwdkZyfpBhsXse": 0,  // 税务机关代开的增值税专用发票不含税销售额  2
      "yzSkPtfpBhsXse": 0,    // 税控器具开具的普通发票不含税销售额  3
      "yzBhsXse5": 0,         // （二）应征增值税不含税销售额（5%征收率）  4
      "yzSwdkZyfpBhsXse5": 0, // 税务机关代开的增值税专用发票不含税销售额  5
      "yzSkPtfpBhsXse5": 0,   // 税控器具开具的普通发票不含税销售额  6
      "ysgzBhsXse": 0,        // （三）销售使用过的应税固定资产不含税销售额  7
      "ysgzSkPtfpBhsXse": 0,  // 其中：税控器具开具的普通发票不含税销售额  8
      "msXse": 0,             // （四）免税销售额  9
      "msXwqyXse": 0,         // 其中：小微企业免税销售额  10
      "msWdqzdXse": 0,        // 未达起征点销售额  11
      "msQtXse": 0,           // 其他免税销售额  12
      "ckmsXse": 0,           // （五）出口免税销售额  13
      "ckmsSkPtfpXse": 0,     // 其中：税控器具开具的普通发票销售额  14
      "hdxse": 0,             // 核定销售额  15
      "ynSeBq": 0,            // 本期应纳税额  16
      "hdynse": 0,            // 核定应纳税额 17
      "ynSeJzeBq": 0,         // 本期应纳税额减征额  18
      "mseBq": 0,             // 本期免税额  19
      "xwqyMseBq": 0,         // 其中：小微企业免税额  20
      "wdqzdMseBq": 0,        // 未达起征点免税额  21
      "ynSeHj": 0,            // 应纳税额合计  22
      "yjSeBq": 0,            // 本期预缴税额  23
      "ybtSeBq": 0,           // 本期应补（退）税额  24
      "bdcxse": 0             // 不动产销售额
    },
    "jsmxb": [    // 减税明细
      {
        "jmslx": "01",
        "jmxzDm": "",
        "jmxzMc": "",
        "jmsxDm": "",
        "qcyeMsxse": 0,
        "bqfseSjkce": 0,
        "bqydjseKchmsxse": 0,
        "bqsjdjseMsjxse": 0,
        "qmyeMse": 0
      }
    ],
    "msmxb": [  // 免税明细
      {
        "jmslx": "02",
        "jmxzDm": "",
        "jmxzMc": "",
        "jmsxDm": "",
        "qcyeMsxse": 0,
        "bqfseSjkce": 0,
        "bqydjseKchmsxse": 0,
        "bqsjdjseMsjxse": 0,
        "qmyeMse": 0
      }],
    "ckms": 0,
    "kjfw": 0,
    "is2019s": "N",         // 是否2019年减征
    "bqxseHj": 0,           // 本期销售额合计
    "qzd": 0,               // 本期起征点
    "grsds": {              // 个税申报数据
      "nsrsbh": "",       // 纳税人识别号
      "nsrmc": "",        // 纳税人名称
      "skssqq": "",       // 属期起
      "skssqz": "",       // 属期止
      "zsxmDm": "",       // 征收项目代码   1
      "zsxmMc": "",       // 征收项目名称
      "zspmDm": "",       // 征收品目代码   2
      "zspmMc": "",       // 征收品目名称
      "zszmDm": "",       // 征收子目代码   3
      "zszmMc": "",       // 征收字母名称
      "srze": 0,          // 收入总额       4
      "hdsrze": 0,        // 核定收入总额   5
      "srzeDefault": 0,   // 收入总额(更正带入)
      "jcx": 0,           // 减除项          6
      "hdzsl": 0,         // 核定征收率      7
      "ynse": 0,          // 应纳税额        8
      "bqybtse": 0        // 本期应补退税额   9
    },
    "fjs": [],              // 附加税
    "fjsJc": {              // 附加税基础信息
      "nsrsbh": "",       // 纳税人识别号
      "nsrmc": "",        // 纳税人名称

      "skssqq": "",       // 属期起
      "skssqz": "",       // 属期止

      "djlx": "",         // 登记类型
      "bqsfsyxgmyhzc": "",        // 增值税小规模减征标志

      "cjrhqyBz": "N",            // 产教融合减征适用标志
      "jzbl": 0.3,                // 产教融合减征比例
      "bqsfsycjrhxqyjzzc": "",    // 产教融合减征是否享用
      "dqxztze": 0,               // 当期新增投资额
      "dqxztzeDef": 0,            // 当期新增投资额(保留上次选“是”时的数据)
      "sqldkdmje": 0,             // 上期留抵可抵免金额
      "jzxqkdmje": 0,             // 结转下期可抵免金额

      "djzclxDm": "",     // 登记注册类型代码
      "djzclxMc": "",     // 登记注册类型名称

      "sfzjlx": "",       // 身份证件类型
      "sfzjlxMc": "",     // 身份证件类型名称
      "zjhm": "",         // 证件号码

      "hyDm": "",         // 行业代码
      "hyMc": "",         // 行业名称

      "lxfs": "",         // 联系方式
      "zzsYbtse": 0       // 增值税应补退税额
    },
    "fjsgz": {},            // 附加税更正数据
    "grsdsgz": {}           // 个税更正数据
  };

  /**
   * 初始化模版对象
   *
   * @param {Object} _nsrInfo 调用方传入的纳税人基本信息
   * @param {Object} _defaultValue 调用方传入的缓存数据
   */
  var __init__ = function (_nsrInfo, _defaultValue, platform) {
    if (typeof _nsrInfo == "string") {
      _nsrInfo = JSON.parse(_nsrInfo);
    }
    if (typeof _defaultValue == "string") {
      _defaultValue = JSON.parse(_defaultValue);
    }
    // 计算初始化数据，全部数据采用深度克隆和空对象继承的方式处理，方式在程序运行中对基础对象信息产生修改
    var mainTableColumnNames = tools.deepClone(MAIN_TABLE_COLUMN_NAMES);    // 展示信息的克隆
    var nsrInfo = JSON.extend({}, DEFAULT_NSR_INFO, _nsrInfo);              // 纳税人信息的克隆
    var gridValues = JSON.extend({}, DEFAULT_GRID_VALUES, _defaultValue);   // 申报数据的克隆
    var inputAlias = new Array(mainTableColumnNames.length * 2);            // 这个是为了和APP通讯使用的对象结构，按照输入顺序整理
    var alias = {bys: {}, bysFw: {}};                                       // 这个是给自动计算和校验使用的，按照行号定义key值

    gridValues.isAndroid = platform == "android";

    // 基础数据中没有增值税，则视同增值税已申报
    if (_nsrInfo.zzs == undefined) {
      // 合伙企业
      nsrInfo.ishh = true;
      nsrInfo.zzs.ysbBz = "Y";

      if (nsrInfo.grsds != undefined && (nsrInfo.grsds.returnCode == undefined || nsrInfo.grsds.returnCode == "00")) {
        // 复制个税基础信息到增值税
        nsrInfo.zzs.sssqQ = nsrInfo.grsds.skssqq;
        nsrInfo.zzs.sssqZ = nsrInfo.grsds.skssqz;
      }
      if (nsrInfo.fjs != undefined && (nsrInfo.fjs.returnCode == undefined || nsrInfo.fjs.returnCode == "00")) {
        nsrInfo.zzs.sssqQ = nsrInfo.fjs.skssqq;
        nsrInfo.zzs.sssqZ = nsrInfo.fjs.skssqz;
      } else {
        nsrInfo.fjs = {"fjsYsbBz": "Y"};
      }
    } else if (_nsrInfo.zzs.returnCode != "00") {
      nsrInfo.zzs.ysbBz = "Y";
    }

    /**
     * 报表显示
     */
    if (whasZzs(nsrInfo)) {
      // 增值税未申报
      showBb('zzs');
    } else {
      // 增值税已申报
      if (whasFjs(nsrInfo)) {
        // 有附加税且未申报
        showBb('fjs');
      } else {
        // 没有附加税或者附加税已申报
        if (whasGs(nsrInfo)) {
          // 有个税且未申报
          showBb('gs');
        } else {
          // 都申报了
          showBb('zzs');
        }
      }
    }

    // 年份判断
    if (whasZzs(nsrInfo)) {
      var year = tools.parseValue(nsrInfo.zzs.sssqQ.substring(0, 4), "float2");
      nsrInfo.is2019s = year >= 2019;
    } else if (whasFjs(nsrInfo)) {
      var sqq = nsrInfo.gzbz == "Y" ? gridValues.fjsgz.sssqQ : nsrInfo.fjs.skssqq;
      var year = tools.parseValue(sqq.substring(0, 4), "float2");
      nsrInfo.is2019s = year >= 2019;
    } else if (whasGs(nsrInfo)) {
      var sqq = nsrInfo.gzbz == "Y" ? gridValues.grsdsgz.skssqq : nsrInfo.grsds.skssqq;
      var year = tools.parseValue(sqq.substring(0, 4), "float2");
      nsrInfo.is2019s = year >= 2019;
    }

    /**
     * 增值税预算
     */
    gridValues.is2019s = nsrInfo.is2019s ? "Y" : "N";
    if (!nsrInfo.ishh) {
      gridValues.qzd = nsrInfo.zzs.qzd;

      if (nsrInfo.gzbz != "Y") {
        // 正常申报
        gridValues.bys.hdxse = tools.parseValue(nsrInfo.zzs.hdxseHw, "float2");         // 货物劳务 核定销售额
        gridValues.bysFw.hdxse = tools.parseValue(nsrInfo.zzs.hdxseFw, "float2");       // 服务 核定销售额
        gridValues.bys.hdynse = tools.parseValue(nsrInfo.zzs.hdynseHw, "float2");       // 货物劳务 核定销售额
        gridValues.bysFw.hdynse = tools.parseValue(nsrInfo.zzs.hdynseFw, "float2");     // 货物劳务 核定销售额
        gridValues.bys.yjSeBq = tools.parseValue(nsrInfo.zzs.yshwYjs, "float2");        // 货物劳务 本期预缴税额
        gridValues.bysFw.yjSeBq = tools.parseValue(nsrInfo.zzs.ysfwYjs, "float2");      // 服务 本期预缴税额
      } else {
        // 更正
        // 更正时，没有减免事项代码则把减免性质代码置空
        for (var i = 0; i < gridValues.jsmxb.length; i++) {
          var tmp = gridValues.jsmxb[i];
          if (tmp.jmsxDm == undefined || tmp.jmsxDm == "") {
            tmp.jmxzDm = "";
          }
        }
        for (var i = 0; i < gridValues.msmxb.length; i++) {
          var tmp = gridValues.msmxb[i];
          if (tmp.jmsxDm == undefined || tmp.jmsxDm == "") {
            tmp.jmxzDm = "";
          }
        }
      }
    }

    var gs_zb;

    /**
     * 个税数据预算
     */
    var initGs = function () {
      if (nsrInfo.grsds != undefined && nsrInfo.grsds.ysbBz != "Y") {

        if ("Y" != nsrInfo.gzbz) {
          //正常申报
          gridValues.grsds.nsrsbh = nsrInfo.grsds.nsrsbh;
          gridValues.grsds.nsrmc = nsrInfo.grsds.nsrmc;
          gridValues.grsds.skssqq = nsrInfo.grsds.skssqq;
          gridValues.grsds.skssqz = nsrInfo.grsds.skssqz;
          gridValues.grsds.zsxmDm = nsrInfo.grsds.zsxmDm;
          gridValues.grsds.zsxmMc = nsrInfo.grsds.zsxmMc;
          gridValues.grsds.zspmDm = nsrInfo.grsds.zspmDm;
          gridValues.grsds.zspmMc = nsrInfo.grsds.zspmMc;

          gridValues.grsds.jcx = tools.parseValue(nsrInfo.grsds.jcx, "float2");
          gridValues.grsds.hdsrze = tools.parseValue(nsrInfo.grsds.hdxse, "float2");

          if (nsrInfo.ishh) {
            // 合伙企业，默认收入总额等于个税核定销售额
            gridValues.grsds.srze = gridValues.grsds.hdsrze;
          } else {
            gridValues.grsds.srze = calculateSrze(nsrInfo, gridValues, true);
          }
        } else {
          gridValues.grsds.nsrsbh = gridValues.grsdsgz.nsrsbh;
          gridValues.grsds.nsrmc = gridValues.grsdsgz.nsrmc;
          gridValues.grsds.skssqq = gridValues.grsdsgz.skssqq;
          gridValues.grsds.skssqz = gridValues.grsdsgz.skssqz;

          gridValues.grsds.zsxmDm = gridValues.grsdsgz.zsxmDm;
          gridValues.grsds.zsxmMc = gridValues.grsdsgz.zsxmMc;
          gridValues.grsds.zspmDm = gridValues.grsdsgz.zspmDm;
          gridValues.grsds.zspmMc = gridValues.grsdsgz.zspmMc;
          gridValues.grsds.zszmDm = gridValues.grsdsgz.zszmDm;
          gridValues.grsds.zszmMc = gridValues.grsdsgz.zszmMc;

          gridValues.grsds.srzeDefault = gridValues.grsdsgz.srze;
          gridValues.grsds.srze = gridValues.grsdsgz.srze;
          gridValues.grsds.hdsrze = gridValues.grsdsgz.hdxse;
          gridValues.grsds.jcx = gridValues.grsdsgz.jcx;
          gridValues.grsds.hdzsl = gridValues.grsdsgz.hdzsl;
          gridValues.grsds.ynse = gridValues.grsdsgz.ynse;
          gridValues.grsds.bqybtse = gridValues.grsdsgz.bqybtse;

          gridValues.grsds.sbuuid = gridValues.grsdsgz.sbuuid;        // 申报uuid
          gridValues.grsds.pzxh = gridValues.grsdsgz.pzxh;            // 凭证序号
        }
        if (nsrInfo.grsds.nsqxDm.length < 1) {
          var q = tools.parseValue(gridValues.grsds.skssqq, "float2");
          var z = tools.parseValue(gridValues.grsds.skssqz, "float2");
          nsrInfo.grsds.nsqxDm = z - q > 100 ? "08" : "06";
        }
        // 季报
        nsrInfo.grsds.isSeason = "08" == nsrInfo.grsds.nsqxDm;
      }
    };

    /**
     * 附加税数据预算
     */
    var initFjs = function () {
      if (nsrInfo.fjs != undefined && nsrInfo.fjs.fjsYsbBz != "Y" && nsrInfo.fjs.items != undefined) {
        var xse = calculateSrze(nsrInfo, gridValues, false);

        var qzd = ("08" == nsrInfo.zzs.nsqxDm) ? 300000 : 100000;

        if (nsrInfo.gzbz == "Y") {
          // 更正申报
          gridValues.fjsJc.nsrsbh = gridValues.fjsgz.nsrsbh;
          gridValues.fjsJc.nsrmc = gridValues.fjsgz.nsrmc;
          gridValues.fjsJc.skssqq = gridValues.fjsgz.sssqQ;         // 属期起
          gridValues.fjsJc.skssqz = gridValues.fjsgz.sssqZ;         // 属期止
          if (nsrInfo.zzs.nsqxDm.length < 1) {
            var q = tools.parseValue(gridValues.fjsJc.skssqq, "float2");
            var z = tools.parseValue(gridValues.fjsJc.skssqz, "float2");
            nsrInfo.zzs.nsqxDm = z - q > 100 ? "08" : "06";
          }
          qzd = ("08" == nsrInfo.zzs.nsqxDm) ? 300000 : 100000;

          gridValues.fjsJc.djlx = gridValues.fjsgz.djlx == undefined || gridValues.fjsgz.djlx == "" ? "1" : gridValues.fjsgz.djlx;
          gridValues.fjsJc.lxfs = gridValues.fjsgz.lxfs;            // 联系方式
          gridValues.fjsJc.djzclxDm = gridValues.fjsgz.djzclxDm;    // 登记注册类型代码
          gridValues.fjsJc.sfzjlx = gridValues.fjsgz.sfzjlx;        // 身份证件类型代码
          gridValues.fjsJc.sfzjlxMc = gridValues.fjsgz.sfzjlxMc;    // 身份证件类型名称
          gridValues.fjsJc.zjhm = gridValues.fjsgz.zjhm;            // 证件号码
          gridValues.fjsJc.hyDm = gridValues.fjsgz.hyDm;            // 行业代码

          gridValues.fjsJc.sbuuid = gridValues.fjsgz.sbuuid;        // 申报uuid
          gridValues.fjsJc.pzxh = gridValues.fjsgz.pzxh;            // 凭证序号

          gridValues.fjsJc.sfjkBz = gridValues.fjsgz.sfjkBz;                              // 附加税是否缴款标志
          gridValues.fjsJc.yjkje = tools.parseValue(gridValues.fjsgz.yjkJe, "float2");    // 附加税已缴款金额

          gridValues.fjsJc.bqsfsyxgmyhzc = gridValues.fjsgz.bqsfsyxgmyhzc;    // 增值税小规模减征(Y：是，N：否)

          gridValues.fjsJc.cjrhqyBz = gridValues.fjsgz.cjrhqyBz;  // 产教融合标志
          gridValues.fjsJc.jzbl = tools.parseValue(gridValues.fjsgz.jzbl, "float2");
          gridValues.fjsJc.bqsfsycjrhxqyjzzc = gridValues.fjsgz.bqsfsycjrhxqyjzzc;    // 产教融合减征(Y：是，N：否)
          gridValues.fjsJc.dqxztze = tools.parseValue(gridValues.fjsgz.dqxztze, "float2");
          gridValues.fjsJc.dqxztzeDef = gridValues.fjsJc.dqxztze;
          gridValues.fjsJc.sqldkdmje = tools.parseValue(gridValues.fjsgz.sqldkdmje, "float2");
          gridValues.fjsJc.jzxqkdmje = tools.parseValue(gridValues.fjsgz.jzxqkdmje, "float2");

          // 按照zsxmDm升序排序，城建税在最上
          gridValues.fjsgz.fjsSbxx = gridValues.fjsgz.fjsSbxx.sort(tools.sortBy("zsxmDm", true));
          // 更正时，以更正数据中的items为准
          nsrInfo.fjs.items = [];

          for (var i = 0; i < gridValues.fjsgz.fjsSbxx.length; i++) {
            var item = gridValues.fjsgz.fjsSbxx[i];
            // 销售额为0，但是有一般增值税，则可能增值税销售额获取异常
            var isXseUnknow = tools.parseValue(item.ybzzs, "float2") != 0 && xse == 0;

            var jzbl = (item.phjzbl == undefined || item.phjzbl == "") ? 0 : tools.parseValue(item.phjzbl, "float2");
            // 其他行政事业性收费、教育费、地方教育，如果当期销售额<= 10万（月）或者30万（季），应补退大于0时减免性质自动带出并免征，否则锁死
            var mz = ("30499" == item.zsxmDm || "30203" == item.zsxmDm || "30216" == item.zsxmDm) && !isXseUnknow && xse <= qzd;
            switch (item.zsxmDm) {
              case "30499":
                // 其他
                break;
              case "30203":
                // 教育
                gridValues.fjsJc.jzbl_jy = jzbl;
                break;
              case "30216":
                // 地方教育
                gridValues.fjsJc.jzbl_dfjy = jzbl;
                break;
              case "10109":
                // 城建税
                gridValues.fjsJc.jzbl_cjs = jzbl;
                break
            }

            var se = Math.max(item.bqynsfe - item.jme, 0);
            var max = tools.parseValue(nsrInfo.is2019s && gridValues.fjsJc.bqsfsyxgmyhzc == "Y" ? (se * item.phjzbl / 100) : 0, "float2");
            nsrInfo.fjs.items.push({
              "zsxmDm": item.zsxmDm,
              "rdpzuuid": item.rdpzuuid,
              "sl": "0.07",
              "yjs": tools.parseValue(item.sl1, "float2"),
              "zsxmMc": item.zsxmMc,
              "zzsldtse": tools.parseValue(item.zzsmdse, "float2"),
              "phjzbl": jzbl,
              "zspmMc": "",
              "zspmDm": item.zspmDm
            });
            gridValues.fjs.push({
              "ewbhxh": i + 1,                // 行号
              "zsxmDm": item.zsxmDm,          // 征收项目代码
              "zsxmMc": item.zsxmMc,          // 征收项目名称
              "zspmDm": item.zspmDm,          // 征收品目代码
              "rdpzuuid": item.rdpzuuid,      // 认定凭证uuid

              "ybzzsDefault": tools.parseValue(item.ybzzs, "float2"),         // 一般增值税更正之前
              "ybzzs": tools.parseValue(item.ybzzs, "float2"),                // 一般增值税
              "zzsmdse": tools.parseValue(item.zzsmdse, "float2"),            // 增值税免抵税额
              "xfs": tools.parseValue(item.xfs, "float2"),                    // 消费税
              "yys": tools.parseValue(item.yys, "float2"),                    // 营业税
              "hj": tools.parseValue(item.hj, "float2"),                      // 合计
              "sl1": tools.parseValue(item.sl1, "float2"),                    // 税率
              "sl2": tools.parseValue(item.sl1 * 100, "float2") + "%",
              "bqynsfe": tools.parseValue(item.bqynsfe, "float2"),            // 本期应纳税额
              "jmxzDm": item.jmxzDm,                                          // 减免性质代码
              "jme": tools.parseValue(item.jmse, "float2"),                   // 减免额
              "phjzbl": jzbl, // 本期增值税减征率
              "phjmse": tools.parseValue(item.phjmse, "float2"),              // 本期增值税减免
              "phjmseMax": max,                                               // 本期增值税减免最大值

              "bqcjrhxqydmje": tools.parseValue(item.bqcjrhxqydmje, "float2"),// 本期抵免额

              "bqyjse": tools.parseValue(item.bqyjse, "float2"),              // 本期已缴税额
              "bqybtse": tools.parseValue(item.bqybtse, "float2")             // 本期应补税额
              ,
              "lsbbz": item.lsbbz,
              "ssjmxzDm": item.ssjmxzDm,
              "mz": mz                                                        // 是否免征
            });
          }
        } else {
          // 正常申报
          gridValues.fjsJc.nsrsbh = nsrInfo.nsrsbh;            // 纳税人识别号
          gridValues.fjsJc.nsrmc = nsrInfo.nsrmc;              // 纳税人名称
          gridValues.fjsJc.skssqq = nsrInfo.fjs.skssqq;        // 属期起
          gridValues.fjsJc.skssqz = nsrInfo.fjs.skssqz;        // 属期止
          gridValues.fjsJc.djzclxDm = nsrInfo.fjs.djzclxDm;    // 登记注册类型代码
          gridValues.fjsJc.djzclxMc = nsrInfo.fjs.djlx;        // 登记注册类型名称
          gridValues.fjsJc.sfzjlx = nsrInfo.fjs.sfzjLx;        // 身份证件类型代码
          gridValues.fjsJc.sfzjlxMc = nsrInfo.fjs.sfzjlxMc;    // 身份证件类型名称
          gridValues.fjsJc.zjhm = nsrInfo.fjs.zjhm;            // 证件号码
          gridValues.fjsJc.hyDm = nsrInfo.fjs.sshy;            // 行业代码
          gridValues.fjsJc.hyMc = nsrInfo.fjs.hyMc;            // 行业名称
          gridValues.fjsJc.lxfs = nsrInfo.fjs.lxfs;            // 联系方式
          gridValues.fjsJc.djlx = "1";                         // 登记类型
          if (nsrInfo.zzs.nsqxDm.length < 1) {
            var q = tools.parseValue(gridValues.fjsJc.skssqq, "float2");
            var z = tools.parseValue(gridValues.fjsJc.skssqz, "float2");
            nsrInfo.zzs.nsqxDm = z - q > 100 ? "08" : "06";
          }
          qzd = ("08" == nsrInfo.zzs.nsqxDm) ? 300000 : 100000;

          gridValues.fjsJc.bqsfsyxgmyhzc = "Y";                // 增值税小规模减征标志(Y:是，N:否)

          gridValues.fjsJc.bqsfsycjrhxqyjzzc = nsrInfo.fjs.cjrhqyBz == "Y" ? "Y" : "N";               // 产教融合减征标志(Y:是，N:否)
          gridValues.fjsJc.jzbl = tools.parseValue(nsrInfo.fjs.jzbl, "float2");                       // cjrhqyBz不为Y时，服务器不返回jzbl字段
          gridValues.fjsJc.sqldkdmje = tools.parseValue(nsrInfo.fjs.sqldkdmje, "float2");

          nsrInfo.fjs.items = nsrInfo.fjs.items.sort(tools.sortBy("zsxmDm", true));

          for (var i = 0; i < nsrInfo.fjs.items.length; i++) {
            var item = nsrInfo.fjs.items[i];
            item.slStr = tools.parseValue(item.sl * 100, "float2") + "%";

            var jzbl = tools.parseValue(item.phjzbl, "float2");
            // 其他行政事业性收费、教育费、地方教育，如果当期销售额<= 10万（月）或者30万（季），应补退大于0时减免性质自动带出并免征，否则锁死
            var mz = ("30499" == item.zsxmDm || "30203" == item.zsxmDm || "30216" == item.zsxmDm) && xse <= qzd;
            switch (item.zsxmDm) {
              case "30499":
                // 其他
                break;
              case "30203":
                // 教育
                gridValues.fjsJc.jzbl_jy = jzbl;
                break;
              case "30216":
                // 地方教育
                gridValues.fjsJc.jzbl_dfjy = jzbl;
                break;
              case "10109":
                // 城建税
                gridValues.fjsJc.jzbl_cjs = jzbl;
                break
            }
            gridValues.fjs.push({
              "ewbhxh": i + 1,            // 行号
              "zsxmDm": item.zsxmDm,      // 征收项目代码
              "zsxmMc": item.zsxmMc,      // 征收项目名称
              "zspmDm": item.zspmDm,      // 征收品目代码
              "rdpzuuid": item.rdpzuuid,  // 认定凭证uuid

              "ybzzs": tools.parseValue(nsrInfo.zzs.xgmYbtse, "float2"),                  // 一般增值税
              "zzsmdse": tools.parseValue(item.zzsldse, "float2"),               // 增值税免抵税额
              "xfs": 0,                   // 消费税
              "yys": 0,                   // 营业税
              "hj": 0,                    // 合计
              "sl1": tools.parseValue(item.sl, "float2"),         // 税率
              "sl2": item.slStr,
              "bqynsfe": 0,               // 本期应纳税额
              "jmxzDm": "",               // 减免性质代码
              "phjzbl": jzbl,             // 本期增值税减征率
              "jme": 0,                   // 减免额
              "phjmse": 0,                // 增值税减免
              "phjmseMax": 0,             // 增值税减免最大值

              "bqcjrhxqydmje": 0,                 // 本期抵免额

              "bqyjse": tools.parseValue(item.yjs, "float2"),     // 本期已缴税额
              "bqybtse": -tools.parseValue(item.yjs, "float2")    // 本期应补税额
              ,
              "mz": mz                    // 是否免征
            });
          }
        }

        // 计算产教融合减征分配比例
        var slSum = 0;  // 教育税率 + 地方教育税率
        if (gridValues.fjsJc.bqsfsycjrhxqyjzzc == "Y") {
          for (var i = 0; i < gridValues.fjs.length; i++) {
            var item = gridValues.fjs[i];
            switch (item.zsxmDm) {
              case "30499":
                // 其他
                break;
              case "30203":
                // 教育
                slSum += item.sl1;
                break;
              case "30216":
                // 地方教育
                slSum += item.sl1;
                break;
              case "10109":
                // 城建税
                break
            }
          }
        }
        for (var i = 0; i < gridValues.fjs.length; i++) {
          var item = gridValues.fjs[i];

          if (nsrInfo.gzbz != "Y") {
            item.ybzzs = tools.parseValue(Math.max(tools.parseValue(nsrInfo.zzs.xgmYbtse, "float2") + gridValues.bys.ybtSeBq + gridValues.bysFw.ybtSeBq, 0), "float2");
          }

          item.slSum = slSum;
          // 自动计算3=1+2
          item.hj = tools.parseValue(item.ybzzs + item.zzsmdse, "float2");
          // 自动计算5=3*4
          item.bqynsfe = tools.parseValue(item.hj * item.sl1, "float2");

          if (item.mz) {
            item.jme = item.bqynsfe;

            var dm = "";
            switch (item.zsxmDm) {
              case "30499":
                dm = "0099129999";
                break;
              case "30203":
                dm = "0061042802";
                break;
              case "30216":
                dm = "0061042802";
                break;
            }
            if (item.bqynsfe > 0) {
              item.jmxzDm = dm;
            } else {
              item.jmxzDm = "";
            }
          }

          var se = Math.max(item.bqynsfe - item.jme, 0);
          item.phjmseMax = tools.parseValue(nsrInfo.is2019s && gridValues.fjsJc.bqsfsyxgmyhzc == "Y" ? (se * item.phjzbl / 100) : 0, "float2");
          item.phjmse = item.phjmseMax;

        }
        gridValues.fjsJc.jzxqkdmje = tools.parseValue(gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje, "float2");
        var jzSum = 0;
        var isAlljz = isCjrhAlljz(gridValues);
        for (var i = 0; i < gridValues.fjs.length; i++) {
          var item = gridValues.fjs[i];
          var ynse = Math.max(item.bqynsfe - item.jme - item.phjmse, 0);
          if (gridValues.fjsJc.bqsfsycjrhxqyjzzc == "Y" && (item.zsxmDm == "30203" || item.zsxmDm == "30216")) {
            var kdme = gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje;
            var itemkdme = tools.parseValue(kdme * item.sl1 / item.slSum, "float2");
            item.bqcjrhxqydmje = isAlljz ? ynse : itemkdme;

            ynse = tools.parseValue(Math.max(ynse - item.bqcjrhxqydmje, 0), "float2");
          } else {
            item.bqcjrhxqydmje = 0;
          }
          jzSum += item.bqcjrhxqydmje;
          // 自动计算11=5-7-8-9-10
          item.bqybtse = tools.parseValue(ynse - item.bqyjse, "float2");
        }
        gridValues.fjsJc.jzxqkdmje -= jzSum;
      }
    };

    window.onload = function (ev) {
      if ("Y" == nsrInfo.gzbz && "Y" == nsrInfo.zzs.zzsGzbz) {
        // 个税计税依据判断
        checkGsYj();

        // 附加税计税依据判断
        setTimeout(checkFjsYj, 600);
      }
    };

    window.checkGsYj = function () {
      if ("Y" == nsrInfo.gzbz && nsrInfo.grsds != undefined && nsrInfo.grsds.ysbBz != 'Y') {
        var gsYj = calculateSrze(nsrInfo, gridValues, true);

        if (gridValues.grsds.srze < gsYj) {
          alert("个人所得税 - 第4行 收入总额(" + gridValues.grsds.srze + ") 必须大于等于增值税本期实际销售额与核定销售额的最大值(" + calculateSrze(nsrInfo, gridValues, false) + ")，并且必须大于等于个人所得税核定销售额(" + tools.parseValue(gridValues.grsds.hdsrze, "float2") + ")");
          gridValues.grsds.srze = gsYj;
        }
      }
    };
    /**
     * 检查更正申报时附加税计税依据是否正确
     */
    window.checkFjsYj = function () {
      if ("Y" == nsrInfo.gzbz && nsrInfo.fjs != undefined && nsrInfo.fjs.fjsYsbBz != 'Y') {
        // 附加税计税依据判断
        var fjsYj = tools.parseValue(nsrInfo.zzs.xgmYbtse, "float2") + tools.parseValue(gridValues.bys.ybtSeBq, "float2") + tools.parseValue(gridValues.bysFw.ybtSeBq, "float2");

        var fjsEdit = false;
        var fjsMsg = "";
        for (var i = 0; i < gridValues.fjs.length; i++) {
          var item = gridValues.fjs[i];
          if (item.ybzzs < fjsYj) {
            fjsEdit = true;
            fjsMsg += (fjsMsg.length < 1 ? "" : "、") + item.zsxmMc + ":" + item.ybzzs;
          }
        }
        if (fjsEdit) {
          if (confirm("附加税一般增值税(" + fjsMsg + ")小于增值税本期应补退税额(" + fjsYj + ")，建议根据增值税本期应补退税额进行修正，是否修正？")) {
            for (var i = 0; i < gridValues.fjs.length; i++) {
              var item = gridValues.fjs[i];
              item.ybzzsDefault = fjsYj;
              if (item.ybzzs < fjsYj) {
                item.ybzzs = fjsYj;

                // 自动计算3=1+2
                item.hj = tools.parseValue(item.ybzzs + item.zzsmdse, "float2");
                // 自动计算5=3*4
                item.bqynsfe = tools.parseValue(item.hj * item.sl1, "float2");

                if (item.mz) {
                  item.jme = item.bqynsfe;

                  var dm = "";
                  switch (item.zsxmDm) {
                    case "30499":
                      dm = "0099129999";
                      break;
                    case "30203":
                      dm = "0061042802";
                      break;
                    case "30216":
                      dm = "0061042802";
                      break;
                  }
                  if (item.bqynsfe > 0) {
                    item.jmxzDm = dm;
                  } else {
                    item.jmxzDm = "";
                  }
                }

                var se = Math.max(item.bqynsfe - item.jme, 0);
                item.phjmseMax = tools.parseValue(nsrInfo.is2019s && gridValues.fjsJc.bqsfsyxgmyhzc == "Y" ? (se * item.phjzbl / 100) : 0, "float2");
                item.phjmse = item.phjmseMax;
              }
            }
            var jzSum = 0;
            gridValues.fjsJc.jzxqkdmje = tools.parseValue(gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje, "float2");
            var isAlljz = isCjrhAlljz(gridValues);
            for (var i = 0; i < gridValues.fjs.length; i++) {
              var item = gridValues.fjs[i];
              var ynse = Math.max(item.bqynsfe - item.jme - item.phjmse, 0);
              if (gridValues.fjsJc.bqsfsycjrhxqyjzzc == "Y" && (item.zsxmDm == "30203" || item.zsxmDm == "30216")) {
                var kdme = gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje;
                var itemkdme = tools.parseValue(kdme * item.sl1 / item.slSum, "float2");
                item.bqcjrhxqydmje = isAlljz ? ynse : itemkdme;

                ynse = tools.parseValue(Math.max(ynse - item.bqcjrhxqydmje, 0), "float2");
              } else {
                item.bqcjrhxqydmje = 0;
              }
              jzSum += item.bqcjrhxqydmje;
              // 自动计算11=5-7-8-9-10
              item.bqybtse = tools.parseValue(ynse - item.bqyjse, "float2");
            }
            gridValues.fjsJc.jzxqkdmje -= jzSum;
          }
        }
      }
    };

    /**
     * 读取数据
     * @param {Object} cache
     * @param {Object} index
     */
    var getValue = function (cache, index) {
      return gridValues[cache][alias[cache][index].name];
    };

    /**
     * 设置数据
     * @param {Object} cache
     * @param {Object} index
     */
    var setValue = function (cache, index, value) {
      var type = alias[cache][index].type;
      gridValues[cache][alias[cache][index].name] = tools.parseValue(value, type);
      autoCompute(cache, alias[cache][index].name, false);
    };

    /**
     * 自动计算
     * @param {Object} cache 本次修改的内容所属列
     * @param {Object} name 本次修改的内容节点
     * @param {Object} all 全部计算
     */
    var autoCompute = function (cache, name, all) {
      // 应税货物及劳务 自动计算
      if ("bysFw" !== cache) {
        var __cache__ = "bys";
        // 9=10+11+12 （来自表样）
        if (all || alias[__cache__][10].name == name || alias[__cache__][11].name == name || alias[__cache__][12].name == name) {
          setValue(__cache__, 9, getValue(__cache__, 10) + getValue(__cache__, 11) + getValue(__cache__, 12));
          if (!all) {
            autoCompute(cache, alias[__cache__][9].name);
          }
        }
        // 逾期未认定标志为N 第16行_第1列"="第1行_第1列"+"第7行_第1列"*0.03（来自需求整理文档）
        // 逾期未认定标志为Y时不自动计算
        if (nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y" && (all || alias[__cache__][1].name == name || alias[__cache__][7].name == name)) {
          setValue(__cache__, 16, (getValue(__cache__, 1) + getValue(__cache__, 7)) * 0.03);
          if (!all) {
            autoCompute(cache, alias[__cache__][16].name);
          }
        }
        // “第19行_第1列”应=“第9行_第1列”*%3（来自需求整理文档）
        if (all || alias[__cache__][9].name == name) {
          setValue(__cache__, 19, getValue(__cache__, 9) * 0.03);
          if (!all) {
            autoCompute(cache, alias[__cache__][19].name);
          }
        }
        // “第20行_第1列”应=“第10行_第1列”*%3（来自需求整理文档）
        if (all || alias[__cache__][10].name == name) {
          setValue(__cache__, 20, getValue(__cache__, 10) * 0.03);
          if (!all) {
            autoCompute(cache, alias[__cache__][20].name);
          }
        }
        // “第21行_第1列”应=“第11行_第1列”*%3（来自需求整理文档）
        if (all || alias[__cache__][11].name == name) {
          setValue(__cache__, 21, getValue(__cache__, 11) * 0.03);
          if (!all) {
            autoCompute(cache, alias[__cache__][21].name);
          }
        }
        // 22=Math.max(16, 17) -18（来自表样）
        if (all || alias[__cache__][16].name == name || alias[__cache__][17].name == name || alias[__cache__][18].name == name) {
          setValue(__cache__, 22, Math.max(getValue(__cache__, 16), getValue(__cache__, 17)) - getValue(__cache__, 18));
          if (!all) {
            autoCompute(cache, alias[__cache__][22].name);
          }
        }
        // 24=22-23（来自表样）
        if (all || alias[__cache__][22].name == name || alias[__cache__][23].name == name) {
          setValue(__cache__, 24, getValue(__cache__, 22) - getValue(__cache__, 23));
          if (!all) {
            autoCompute(cache, alias[__cache__][24].name);
          }
        }
      }
      // 服务、不动产和无形资产 自动计算
      if ("bys" !== cache) {
        // 9=10+11+12 （来自表样）
        // 22=Math.max(16, 17) -18（来自表样）
        // 24=22-23（来自表样）
        var __cache__ = "bysFw";
        // 9=10+11+12 （来自表样）
        if (all || alias[__cache__][10].name == name || alias[__cache__][11].name == name || alias[__cache__][12].name == name) {
          setValue(__cache__, 9, getValue(__cache__, 10) + getValue(__cache__, 11) + getValue(__cache__, 12));
          if (!all) {
            autoCompute(cache, alias[__cache__][9].name);
          }
        }
        // 逾期未认定企业标志是N "第16行_第2列"应="第1行_第2列"*0.03+"第4行_第2列"*0.05（来自需求整理文档）
        if (nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y" && (all || alias[__cache__][1].name == name || alias[__cache__][4].name == name)) {
          setValue(__cache__, 16, getValue(__cache__, 1) * 0.03 + getValue(__cache__, 4) * 0.05);
          if (!all) {
            autoCompute(cache, alias[__cache__][16].name);
          }
        }
        // “第19行_第2列”应=“第9行_第2列”*%3（来自需求整理文档）
        if (all || alias[__cache__][9].name == name) {
          setValue(__cache__, 19, getValue(__cache__, 9) * 0.03);
          if (!all) {
            autoCompute(cache, alias[__cache__][19].name);
          }
        }
        // “第20行_第2列”应=“第10行_第2列”*%3（来自需求整理文档）
        if (all || alias[__cache__][10].name == name) {
          setValue(__cache__, 20, getValue(__cache__, 10) * 0.03);
          if (!all) {
            autoCompute(cache, alias[__cache__][20].name);
          }
        }
        // “第21行_第1列”应=“第11行_第1列”*%3（来自需求整理文档）
        if (all || alias[__cache__][11].name == name) {
          setValue(__cache__, 21, getValue(__cache__, 11) * 0.03);
          if (!all) {
            autoCompute(cache, alias[__cache__][21].name);
          }
        }
        // 22=Math.max(16, 17) -18（来自表样）
        if (all || alias[__cache__][16].name == name || alias[__cache__][17].name == name || alias[__cache__][18].name == name) {
          setValue(__cache__, 22, Math.max(getValue(__cache__, 16), getValue(__cache__, 17)) - getValue(__cache__, 18));
          if (!all) {
            autoCompute(cache, alias[__cache__][22].name);
          }
        }
        // 24=22-23（来自表样）
        if (all || alias[__cache__][22].name == name || alias[__cache__][23].name == name) {
          setValue(__cache__, 24, getValue(__cache__, 22) - getValue(__cache__, 23));
          if (!all) {
            autoCompute(cache, alias[__cache__][24].name);
          }
        }
      }
    };
    (function () {
      // 根据征收类别代码设置应税货物及劳务和服务、不动产和无形资产的可编辑属性
      for (var i = 0; i < mainTableColumnNames.length; i++) {
        var row = mainTableColumnNames[i];
        if (nsrInfo.zzs.szlbDm == "01") {
          // 服务、不动产和无形资产列不可编辑
          row.bysFw.readonly = true;
        }
        if (nsrInfo.zzs.szlbDm == "02") {
          // 应税货物及劳务列不可编辑
          row.bys.readonly = true;
        }
        // 如果企业是逾期未认定企业，限制第12行数据不可编辑
        if (row.index == 12 && nsrInfo.zzs.yqwrdybrBz.toUpperCase() == "Y") {
          row.bysFw.readonly = row.bys.readonly = true;
        }
        // 第10行只有非个体纳税人和非其他个人可以填写
        if (row.index == 10) {
          row.bysFw.readonly = row.bys.readonly = true;
        }
        // 计算别名
        var bysNode = {
          "name": row.name,
          "cache": "bys",
          "label": "【货物及劳务】第" + row.index + "栏：" + row.columnName.replace(new RegExp("　", "gi"), ""),
          "type": row.bys.type,
          "index": 100 + row.index,
          "disabled": row.bys.disabled,
          "readonly": row.bys.readonly
        };

        var bysFwNode = {
          "name": row.name,
          "cache": "bysFw",
          "label": "【服务、不动产和无形资产】第" + row.index + "栏：" + row.columnName.replace(new RegExp("　", "gi"), ""),
          "type": row.bysFw.type,
          "index": 200 + row.index,
          "disabled": row.bysFw.disabled,
          "readonly": row.bysFw.readonly
        };

        alias.bys[i + 1] = inputAlias[i] = bysNode;
        alias.bysFw[i + 1] = inputAlias[i + mainTableColumnNames.length] = bysFwNode;
      }
      // 不动产销售额单独输入框
      var bdcInfos = [{name: 'bdcxse', type: 'float2', title: '本期不动产销售额', row: 1}];
      // 减税附表录入项目及类型
      var jsInfos = [
        {name: 'jmxzDm', type: 'jmxzDm_js', title: "减税性质代码及名称"},
        {name: 'qcyeMsxse', type: 'float2', title: "期初余额"},
        {name: 'bqfseSjkce', type: 'float2', title: "本期发生额"},
        {name: 'bqsjdjseMsjxse', type: 'float2', title: "本期实际抵减税额"}
      ];
      // 免税附表录入项目及类型
      var msInfos = [
        {name: 'jmxzDm', type: 'jmxzDm_ms', title: "免税性质代码及名称"},
        {name: 'qcyeMsxse', type: 'float2', title: "免征增值税项目销售额"},
        {name: 'bqfseSjkce', type: 'float2', title: "免税销售额扣除项目本期实际扣除金额"},
        {name: 'qmyeMse', type: 'float2', title: "免税额"}
      ];
      var msOtherInfos = [
        {name: 'ckms', type: 'float2', title: "出口免税"},
        {name: 'kjfw', type: 'float2', title: "其中：跨境服务"}
      ];

      if (nsrInfo.fjs != undefined && nsrInfo.fjs.fjsYsbBz != "Y") {
        // 附加税录入项目及类型
        var fjsJcInfos = [
          {name: 'sfzjlx', type: 'sfzjlx', title: "身份证件类型"},
          {name: 'zjhm', type: 'string str(30)', title: "身份证件号码"},
          {name: 'lxfs', type: 'string str(30)', title: "联系方式"}
        ];
        var fjsJcInfosCjrh = [
          {name: 'dqxztze', type: 'float2', title: "当期新增投资额"}
        ];
        var fjsInfos = [
          {name: 'zzsmdse', type: 'float2', title: "免抵税额", row: 2},
          {name: 'jmxzDm', type: 'jmxzDm_fjs', title: "减免性质代码", row: 6},
          {name: 'jme', type: 'float2', title: "减免额", row: 7},
          {name: 'bqyjse', type: 'float2', title: "本期已缴税（费）额", row: nsrInfo.is2019s ? 9 : 8},
          {name: 'ybzzs', type: 'float2', title: "一般增值税", row: 1}
        ];
        var fjsInfosMz = [
          {name: 'zzsmdse', type: 'float2', title: "免抵税额", row: 2},
          {name: 'bqyjse', type: 'float2', title: "本期已缴税（费）额", row: nsrInfo.is2019s ? 9 : 8},
          {name: 'ybzzs', type: 'float2', title: "一般增值税", row: 1}
        ];
        var fjsInfosZzsjz = [
          {name: 'zzsmdse', type: 'float2', title: "免抵税额", row: 2},
          {name: 'jmxzDm', type: 'jmxzDm_fjs', title: "减免性质代码", row: 6},
          {name: 'jme', type: 'float2', title: "减免额", row: 7},
          {name: 'phjmse', type: 'float2', title: "本期增值税小规模纳税人减征额", row: 8},
          {name: 'bqyjse', type: 'float2', title: "本期已缴税（费）额", row: 9},
          {name: 'ybzzs', type: 'float2', title: "一般增值税", row: 1}
        ];
        var fjsInfosMzZzsjz = [
          {name: 'zzsmdse', type: 'float2', title: "免抵税额", row: 2},
          {name: 'phjmse', type: 'float2', title: "本期增值税小规模纳税人减征额", row: 8},
          {name: 'bqyjse', type: 'float2', title: "本期已缴税（费）额", row: 9},
          {name: 'ybzzs', type: 'float2', title: "一般增值税", row: 1}
        ];
      }

      // 首先进行一次自动计算
      autoCompute("", "", true);
      initGs();
      initFjs();
      /**
       * 标题模版
       */
      var title = new Vue({
        el: "#base_info",
        data: {
          nsr: nsrInfo
        },
        computed: {
          hasZzs: function () {
            return whasZzs(this.nsr);
          },
          hasFjs: function () {
            return whasFjs(this.nsr);
          },
          hasGs: function () {
            return whasGs(this.nsr);
          }
        },
        methods: {
          selectSbb: function () {
            var sbb = document.getElementById("sbb");
            switch (sbb.options[sbb.selectedIndex].value) {
              default:
                showBb('zzs');
                break;
              case "zzs_jm":
                showBb('zzs_fb');
                alert("纳税人本期纳税申报如有减免税情况应如实填写本表，如无减免税情况可在本表对应栏次填零.");
                break;
              case "fjs":
                showBb('fjs');
                break;
              case "gs":
                showBb('gs');
                break;
            }
          }
        }
      });

      /**
       * 增值税主表模版
       */
      var zzsxgmsbb_1 = new Vue({
        el: "#zzsxgmsbb_1",
        data: {
          nsr: nsrInfo,
          rowsData: mainTableColumnNames,
          gridData: gridValues,
          inputData: inputAlias
        },
        methods: {
          setBdcxse: function (index) {
            var notices = {
              "name": bdcInfos[index].name,
              "cache": "mx_" + (index + 1),
              "label": "增值税小规模纳税申报表 —— 表头、" + bdcInfos[index].title,
              "type": bdcInfos[index].type,
              "index": index + 1
            };
            var defaultValue = this.gridData.bysFw[notices.name];
            var value = prompt(JSON.stringify(notices), defaultValue);
            if (!!value) {
              var __value__ = JSON.parse(value);
              this.gridData.bysFw[notices.name] = tools.parseValue(__value__.value, notices.type);

              var step = 0;
              if ("1" == __value__.flag) {
                step = -1;
              } else if ("2" == __value__.flag) {
                step = 1;
              }
              if (step != 0) {
                var nextIndex = index + step;
                if (nextIndex < 0) {
                  nextIndex = bdcInfos.length - 1;
                }
                if (nextIndex >= bdcInfos.length) {
                  nextIndex = 0;
                }
                this.setBdcxse(nextIndex);
              }
            }
          },
          setValue: function (index) {
            var inputData = this.inputData;
            var inputInfo = inputData[index];
            if (inputInfo.disabled || inputInfo.readonly) {
              return;
            }
            var defautValue = this.gridData[inputInfo.cache][inputInfo.name];
            var value = prompt(JSON.stringify(inputInfo), defautValue);
            if (!!value) {
              var __value__ = JSON.parse(value);

              this.gridData[inputInfo.cache][inputInfo.name] = tools.parseValue(__value__.value, inputInfo.type);
              autoCompute(inputInfo.cache, inputInfo.name);
              // 个税收入总额
              this.gridData.grsds.srze = calculateSrze(this.nsr, this.gridData, true);

              if (this.gridData.fjs.length > 0) {
                // 修改销售额，更改附加税免征状态
                var xse = calculateSrze(this.nsr, this.gridData, false);
                var qzd = ("08" == this.nsr.zzs.nsqxDm) ? 300000 : 100000;
                if (this.gridData.fjs.length > 0) {
                  for (var i = 0; i < this.gridData.fjs.length; i++) {
                    var item = this.gridData.fjs[i];
                    // 其他行政事业性收费、教育费、地方教育，如果当期销售额<= 10万（月）或者30万（季），减免性质自动带出，并免征
                    var mz = ("30499" == item.zsxmDm || "30203" == item.zsxmDm || "30216" == item.zsxmDm) && xse <= qzd;
                    item.mz = mz;
                    item.ybzzs = tools.parseValue(Math.max(tools.parseValue(nsrInfo.zzs.xgmYbtse, "float2") + this.gridData.bys.ybtSeBq + this.gridData.bysFw.ybtSeBq, 0), "float2");

                    // 自动计算3=1+2
                    item.hj = tools.parseValue(item.ybzzs + item.zzsmdse, "float2");
                    // 自动计算5=3*4
                    item.bqynsfe = tools.parseValue(item.hj * item.sl1, "float2");

                    if (item.mz) {
                      item.jme = item.bqynsfe;

                      var dm = "";
                      switch (item.zsxmDm) {
                        case "30499":
                          dm = "0099129999";
                          break;
                        case "30203":
                          dm = "0061042802";
                          break;
                        case "30216":
                          dm = "0061042802";
                          break;
                      }
                      if (item.bqynsfe > 0) {
                        item.jmxzDm = dm;
                      } else {
                        item.jmxzDm = "";
                      }
                    } else {
                      item.jme = 0;
                      item.jmxzDm = "";
                    }

                    var se = Math.max(item.bqynsfe - item.jme, 0);
                    item.phjmseMax = tools.parseValue(nsrInfo.is2019s && gridValues.fjsJc.bqsfsyxgmyhzc == "Y" ? (se * item.phjzbl / 100) : 0, "float2");
                    item.phjmse = item.phjmseMax;
                  }

                  var jzSum = 0;
                  gridValues.fjsJc.jzxqkdmje = tools.parseValue(gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje, "float2");
                  var isAlljz = isCjrhAlljz(gridValues);
                  for (var i = 0; i < gridValues.fjs.length; i++) {
                    var item = gridValues.fjs[i];
                    var ynse = Math.max(item.bqynsfe - item.jme - item.phjmse, 0);
                    if (gridValues.fjsJc.bqsfsycjrhxqyjzzc == "Y" && (item.zsxmDm == "30203" || item.zsxmDm == "30216")) {
                      var kdme = gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje;
                      var itemkdme = tools.parseValue(kdme * item.sl1 / item.slSum, "float2");
                      item.bqcjrhxqydmje = isAlljz ? ynse : itemkdme;

                      ynse = tools.parseValue(Math.max(ynse - item.bqcjrhxqydmje, 0), "float2");
                    } else {
                      item.bqcjrhxqydmje = 0;
                    }
                    jzSum += item.bqcjrhxqydmje;
                    // 自动计算11=5-7-8-9-10
                    item.bqybtse = tools.parseValue(ynse - item.bqyjse, "float2");
                  }
                  gridValues.fjsJc.jzxqkdmje -= jzSum;
                }
              }
              // }

              var step = 0;
              if ("1" == __value__.flag) {
                step = -1;
              } else if ("2" == __value__.flag) {
                step = 1;
              }
              if (step != 0) {
                var nextIndex = index;
                while (true) {
                  nextIndex += step;
                  if (nextIndex < 0) {
                    nextIndex = inputData.length - 1;
                  }
                  if (nextIndex >= inputData.length) {
                    nextIndex = 0;
                  }
                  var nextInputInfo = inputData[nextIndex];
                  if (!nextInputInfo.readonly && !nextInputInfo.disabled) {
                    break;
                  }
                }
                this.setValue(nextIndex);
              }
            }
          }
        }
      });

      /**
       * 增值税附表1
       */
      var zzsfb_1 = new Vue({
        el: "#zzsfb_1",
        data: {
          nsr: nsrInfo,
          gridData: gridValues
        },
        computed: {
          totalAmount1: function () {
            var sum = 0;
            for (var i = 0; i < this.gridData.jsmxb.length; i++) {
              sum += this.gridData.jsmxb[i].qcyeMsxse;
            }
            return tools.parseValue(sum, "float2");
          },
          totalAmount2: function () {
            var sum = 0;
            for (var i = 0; i < this.gridData.jsmxb.length; i++) {
              sum += this.gridData.jsmxb[i].bqfseSjkce;
            }
            return tools.parseValue(sum, "float2");
          },
          totalAmount4: function () {
            var sum = 0;
            for (var i = 0; i < this.gridData.jsmxb.length; i++) {
              sum += this.gridData.jsmxb[i].bqsjdjseMsjxse;
            }
            return tools.parseValue(sum, "float2");
          },
          totalAmount12: function () {
            var sum1 = 0;
            for (var i = 0; i < this.gridData.jsmxb.length; i++) {
              sum1 += this.gridData.jsmxb[i].qcyeMsxse;
            }
            var sum2 = 0;
            for (var i = 0; i < this.gridData.jsmxb.length; i++) {
              sum2 += this.gridData.jsmxb[i].bqfseSjkce;
            }
            return tools.parseValue(sum1 + sum2, "float2");
          },
          totalAmount124: function () {
            var sum1 = 0;
            for (var i = 0; i < this.gridData.jsmxb.length; i++) {
              sum1 += this.gridData.jsmxb[i].qcyeMsxse;
            }
            var sum2 = 0;
            for (var i = 0; i < this.gridData.jsmxb.length; i++) {
              sum2 += this.gridData.jsmxb[i].bqfseSjkce;
            }
            var sum4 = 0;
            for (var i = 0; i < this.gridData.jsmxb.length; i++) {
              sum4 += this.gridData.jsmxb[i].bqsjdjseMsjxse;
            }
            return tools.parseValue(sum1 + sum2 - sum4, "float2");
          }
        },
        methods: {
          setValue: function (row, index) {
            var notices = {
              "name": jsInfos[index].name,
              "cache": "mx_" + (row + 1),
              "label": "第" + (row + 2) + "行、" + jsInfos[index].title,
              "type": jsInfos[index].type,
              "index": (row + 1) * 100 + index + 1
            };
            var jmInfo = this.gridData.jsmxb[row];
            var defaultValue = jmInfo[notices.name];
            if (index == 0) {
              defaultValue = jmInfo.jmxzDm == "" ? "" : (jmInfo.jmxzDm + "," + jmInfo.jmsxDm);
            }
            var value = prompt(JSON.stringify(notices), defaultValue);
            if (!!value) {
              var __value__ = JSON.parse(value);
              jmInfo[notices.name] = tools.parseValue(__value__.value, notices.type);

              if (index == 0) {
                if (__value__.value == "" || __value__.value == ",") {
                  jmInfo.jmxzDm = "";
                  jmInfo.jmsxDm = "";
                  // jmInfo["jmxzMc"] = "";
                } else {
                  jmInfo.jmxzDm = tools.parseValue(__value__.value, notices.type).split(",")[0];
                  jmInfo.jmsxDm = tools.parseValue(__value__.value, notices.type).split(",")[1];
                  // jmInfo["jmxzMc"] = tools.parseValue(__value__["value2"], notices.type);
                }
              } else if (index == 1 || index == 2 || index == 3) {
                jmInfo.bqydjseKchmsxse = tools.parseValue(jmInfo.qcyeMsxse + jmInfo.bqfseSjkce, "float2");
                jmInfo.qmyeMse = tools.parseValue(jmInfo.bqydjseKchmsxse - jmInfo.bqsjdjseMsjxse, "float2");
              }

              var step = 0;
              if ("1" == __value__.flag) {
                step = -1;
              } else if ("2" == __value__.flag) {
                step = 1;
              }
              if (step != 0) {
                var nextIndex = index + step;
                if (nextIndex < 0) {
                  nextIndex = jsInfos.length - 1;
                }
                if (nextIndex >= jsInfos.length) {
                  nextIndex = 0;
                }
                this.setValue(row, nextIndex);
              }
            }
          },
          addItem: function () {
            this.gridData.jsmxb.push({
              "jmslx": "01",
              "jmxzDm": "",
              "jmxzMc": "",
              "jmsxDm": "",
              "qcyeMsxse": 0,
              "bqfseSjkce": 0,
              "bqydjseKchmsxse": 0,
              "bqsjdjseMsjxse": 0,
              "qmyeMse": 0
            });
          },
          remove: function (index) {
            this.gridData.jsmxb.splice(index, 1);
          }
        }
      });
      /**
       * 增值税附表2
       */
      var zzsfb_2 = new Vue({
        el: "#zzsfb_2",
        data: {
          nsr: nsrInfo,
          gridData: gridValues
        },
        computed: {
          totalAmount1: function () {
            var sum = 0;
            for (var i = 0; i < this.gridData.msmxb.length; i++) {
              sum += this.gridData.msmxb[i].qcyeMsxse;
            }
            return tools.parseValue(sum, "float2");
          },
          totalAmount11: function () {
            var sum = 0;
            for (var i = 0; i < this.gridData.msmxb.length; i++) {
              sum += this.gridData.msmxb[i].qcyeMsxse;
            }
            sum += this.gridData.ckms + this.gridData.kjfw;
            return tools.parseValue(sum, "float2");
          },
          totalAmount12: function () {
            var sum = 0;
            for (var i = 0; i < this.gridData.msmxb.length; i++) {
              sum += this.gridData.msmxb[i].qcyeMsxse;
            }
            sum += this.gridData.ckms + this.gridData.kjfw;

            var sum2 = 0;
            for (var i = 0; i < this.gridData.msmxb.length; i++) {
              sum2 += this.gridData.msmxb[i].bqfseSjkce;
            }

            return tools.parseValue(sum - sum2, "float2");
          },
          totalAmount2: function () {
            var sum = 0;
            for (var i = 0; i < this.gridData.msmxb.length; i++) {
              sum += this.gridData.msmxb[i].bqfseSjkce;
            }
            return tools.parseValue(sum, "float2");
          },
          totalAmount4: function () {
            var sum = 0;
            for (var i = 0; i < this.gridData.msmxb.length; i++) {
              sum += this.gridData.msmxb[i].bqsjdjseMsjxse;
            }
            return tools.parseValue(sum, "float2");
          },
          totalAmount5: function () {
            var sum = 0;
            for (var i = 0; i < this.gridData.msmxb.length; i++) {
              sum += this.gridData.msmxb[i].qmyeMse;
            }
            return tools.parseValue(sum, "float2");
          }
        },
        methods: {
          setOValue: function (index) {
            // 出口免税和跨境服务
            var notices = {
              "name": msOtherInfos[index].name,
              "cache": "mx_" + (index + 1),
              "label": "第" + (this.gridData.jsmxb.length + (index == 0 ? 3 : 4)) + "行、" + msOtherInfos[index].title,
              "type": msOtherInfos[index].type,
              "index": index + 1
            };
            var defaultValue = this.gridData[notices.name];
            var value = prompt(JSON.stringify(notices), defaultValue);
            if (!!value) {
              var __value__ = JSON.parse(value);
              this.gridData[notices.name] = tools.parseValue(__value__.value, notices.type);

              var step = 0;
              if ("1" == __value__.flag) {
                step = -1;
              } else if ("2" == __value__.flag) {
                step = 1;
              }
              if (step != 0) {
                var nextIndex = index + step;
                if (nextIndex < 0) {
                  nextIndex = jsInfos.length - 1;
                }
                if (nextIndex >= jsInfos.length) {
                  nextIndex = 0;
                }
                this.setOValue(nextIndex);
              }
            }
          },
          setValue: function (row, index) {
            // 正常免税项目
            var notices = {
              "name": msInfos[index].name,
              "cache": "mx_" + (row + 1),
              "label": "第" + (this.gridData.jsmxb.length + row + 5) + "行、" + msInfos[index].title,
              "type": msInfos[index].type,
              "index": (row + 1) * 100 + index + 1
            };
            var jmInfo = this.gridData.msmxb[row];
            var defaultValue = jmInfo[notices.name];
            if (index == 0) {
              defaultValue = jmInfo.jmxzDm == "" ? "" : (jmInfo.jmxzDm + "," + jmInfo.jmsxDm);
            }
            var value = prompt(JSON.stringify(notices), defaultValue);
            if (!!value) {
              var __value__ = JSON.parse(value);
              this.gridData.msmxb[row][notices.name] = tools.parseValue(__value__.value, notices.type);

              if (index == 0) {
                if (__value__.value == "" || __value__.value == ",") {
                  jmInfo.jmxzDm = "";
                  jmInfo.jmsxDm = "";
                  // jmInfo["jmxzMc"] = "";
                } else {
                  jmInfo.jmxzDm = tools.parseValue(__value__.value, notices.type).split(",")[0];
                  jmInfo.jmsxDm = tools.parseValue(__value__.value, notices.type).split(",")[1];
                  // jmInfo["jmxzMc"] = tools.parseValue(__value__["value2"], notices.type);
                }
              } else if (index == 1 || index == 2) {
                jmInfo.bqydjseKchmsxse = tools.parseValue(jmInfo.qcyeMsxse - jmInfo.bqfseSjkce, "float2");
              }

              var step = 0;
              if ("1" == __value__.flag) {
                step = -1;
              } else if ("2" == __value__.flag) {
                step = 1;
              }
              if (step != 0) {
                var nextIndex = index + step;
                if (nextIndex < 0) {
                  nextIndex = jsInfos.length - 1;
                }
                if (nextIndex >= jsInfos.length) {
                  nextIndex = 0;
                }
                this.setValue(row, nextIndex);
              }
            }
          },
          addItem: function () {
            this.gridData.msmxb.push({
              "jmslx": "02",
              "jmxzDm": "",
              "jmxzMc": "",
              "jmsxDm": "",
              "qcyeMsxse": 0,
              "bqfseSjkce": 0,
              "bqydjseKchmsxse": 0,
              "bqsjdjseMsjxse": 0,
              "qmyeMse": 0
            });
          },
          remove: function (index) {
            this.gridData.msmxb.splice(index, 1);
          }
        }
      });

      if (nsrInfo.grsds != undefined && nsrInfo.grsds.ysbBz != "Y") {
        /**
         * 个税主表模版
         */
        gs_zb = new Vue({
          el: "#gszb",
          data: {
            nsr: nsrInfo,
            gridData: gridValues
          },
          computed: {
            calculateHdzsl: function () {
              if (this.nsr.grsds.isSeason) {
                // 季报
                if (this.gridData.grsds.srze <= 90000) {
                  this.gridData.grsds.hdzsl = 0;
                  this.gridData.grsds.zszmDm = "1010602002120044";
                  this.gridData.grsds.zszmMc = "季度经营收入在9万元（含）以下的部分";
                } else if (this.gridData.grsds.srze <= 150000) {
                  this.gridData.grsds.hdzsl = 0.5;
                  this.gridData.grsds.zszmDm = "1010602002120045";
                  this.gridData.grsds.zszmMc = "季度经营收入在9万元至15万元(含）之间";
                } else if (this.gridData.grsds.srze <= 300000) {
                  this.gridData.grsds.hdzsl = 0.8;
                  this.gridData.grsds.zszmDm = "1010602002120046";
                  this.gridData.grsds.zszmMc = "季度经营收入在15万元至30万元（含）之间";
                } else {
                  this.gridData.grsds.hdzsl = 1.4;
                  this.gridData.grsds.zszmDm = "1010602002120047";
                  this.gridData.grsds.zszmMc = "季度经营收入在30万元以上";
                }
              } else {
                // 月报
                if (this.gridData.grsds.srze <= 30000) {
                  this.gridData.grsds.hdzsl = 0;
                  this.gridData.grsds.zszmDm = "1010602002120040";
                  this.gridData.grsds.zszmMc = "月度经营收入在3万元（含）以下的部分";
                } else if (this.gridData.grsds.srze <= 50000) {
                  this.gridData.grsds.hdzsl = 0.5;
                  this.gridData.grsds.zszmDm = "1010602002120041";
                  this.gridData.grsds.zszmMc = "月度经营收入在3万元至5万元(含）之间";
                } else if (this.gridData.grsds.srze <= 100000) {
                  this.gridData.grsds.hdzsl = 0.8;
                  this.gridData.grsds.zszmDm = "1010602002120042";
                  this.gridData.grsds.zszmMc = "月度经营收入在5万元至10万元（含）之间";
                } else {
                  this.gridData.grsds.hdzsl = 1.4;
                  this.gridData.grsds.zszmDm = "1010602002120043";
                  this.gridData.grsds.zszmMc = "月度经营收入在10万元以上";
                }
              }

              return this.gridData.grsds.hdzsl;
            },
            calculateYnse: function () {
              // 应纳税额（8×9-10）
              this.gridData.grsds.ynse = tools.parseValue(Math.max(this.gridData.grsds.srze - this.gridData.grsds.jcx, 0) * this.gridData.grsds.hdzsl / 100, "float2");
              this.gridData.grsds.bqybtse = this.gridData.grsds.ynse;
              return this.gridData.grsds.ynse;
            }
          },
          methods: {
            setValue: function (index) {
              // 个税项目
              var notices = {
                "name": "srze",
                "cache": "gs_1",
                "label": "第4行、收入总额",
                "type": "float2",
                "index": index
              };
              var defaultValue = this.gridData.grsds.srze;
              var value = prompt(JSON.stringify(notices), defaultValue);
              if (!!value) {
                var __value__ = JSON.parse(value);
                if (notices.name == "srze") {
                  // 收入总额 自动带出《增值税纳税申报表（适用小规模纳税人）》累计数的“货物及劳务”和“服务、不动产和无形资产”列第1行+第4行+第7行+第9行+第13行之和，
                  // 可以修改，更正情况下只能改大，正常申报时可改大改小
                  var result = calculateSrze(this.nsr, this.gridData, true);
                  var inputValue = tools.parseValue(__value__.value, notices.type);
                  // 个税收入总额最小值 = max(增值税销售额，增值税核定销售额，个税核定销售额)
                  if ("Y" == this.nsr.gzbz) {
                    var dResult = Math.max(inputValue, this.gridData.grsds.srzeDefault);
                    var srMax = Math.max(result, dResult);
                    if (inputValue < srMax) {
                      alert("更正申报时，个人所得税 - 收入总额 必须大于等于上次申报销售额" + dResult + "与增值税销售额" + result + "的最大值" + srMax);
                      return;
                    }
                    result = srMax;
                  } else {
                    // 销售额1,4,7,9,13
                    var gsHdxse = tools.parseValue(this.gridData.grsds.hdsrze, "float2");
                    if (inputValue < result) {
                      alert("个人所得税 - 收入总额 必须大于等于增值税本期实际销售额与核定销售额的最大值(" + calculateSrze(this.nsr, this.gridData, false) + ")，并且必须大于等于个人所得税核定销售额(" + gsHdxse + "))");
                      return;
                    }
                    result = Math.max(0, inputValue);
                  }

                  this.gridData.grsds.srze = result;
                }

                var step = 0;
                if ("1" == __value__.flag) {
                  step = -1;
                } else if ("2" == __value__.flag) {
                  step = 1;
                }
                if (step != 0) {
                  var nextIndex = index + step;
                  if (nextIndex < 0) {
                    nextIndex = 0;
                  }
                  if (nextIndex >= 1) {
                    nextIndex = 0;
                  }
                  this.setValue(nextIndex);
                }
              }
            }
          }
        });
      }

      if (nsrInfo.fjs != undefined && nsrInfo.fjs.fjsYsbBz != "Y" && nsrInfo.fjs.items != undefined) {
        /**
         * 附加税模版
         */
        var fjs = new Vue({
          el: "#fjszb",
          data: {
            nsr: nsrInfo,
            gridData: gridValues
          },
          computed: {
            needEdit: function () {
              if (this.nsr.gzbz != "Y") {
                return false;
              }
              var fjsYj = tools.parseValue(this.nsr.zzs.xgmYbtse, "float2") + tools.parseValue(this.gridData.bys.ybtSeBq, "float2") + tools.parseValue(this.gridData.bysFw.ybtSeBq, "float2");

              var dif = false;
              for (var i = 0; i < this.gridData.fjs.length; i++) {
                var item = this.gridData.fjs[i];
                if (item.ybzzs < fjsYj) {
                  dif = true;
                }
              }
              return dif;
            },
            countAll5: function () {
              var sum = 0;
              for (var i = 0; i < this.gridData.fjs.length; i++) {
                sum += this.gridData.fjs[i].bqynsfe;
              }
              return tools.parseValue(sum, "float2");
            },
            countAll7: function () {
              var sum = 0;
              for (var i = 0; i < this.gridData.fjs.length; i++) {
                sum += this.gridData.fjs[i].jme;
              }
              return tools.parseValue(sum, "float2");
            },
            countAllZzsjz: function () {
              var sum = 0;
              for (var i = 0; i < this.gridData.fjs.length; i++) {
                sum += this.gridData.fjs[i].phjmse;
              }
              return tools.parseValue(sum, "float2");
            },
            countAll8: function () {
              var sum = 0;
              for (var i = 0; i < this.gridData.fjs.length; i++) {
                sum += this.gridData.fjs[i].bqyjse;
              }
              return tools.parseValue(sum, "float2");
            },
            countAll9: function () {
              var sum = 0;
              for (var i = 0; i < this.gridData.fjs.length; i++) {
                sum += this.gridData.fjs[i].bqybtse;
              }
              return tools.parseValue(sum, "float2");
            },
            countAllCj: function () {
              var sum = 0;
              for (var i = 0; i < this.gridData.fjs.length; i++) {
                sum += this.gridData.fjs[i].bqcjrhxqydmje;
              }
              return tools.parseValue(sum, "float2");
            }
          },
          methods: {
            setRadio: function (e) {
              var radio = e.currentTarget;
              this.gridData.fjsJc.djlx = radio.checked ? (radio.id % 10 + "") : "";
            },
            setRadioZzsjz: function (e) {
              var radio = e.currentTarget;
              this.gridData.fjsJc.bqsfsyxgmyhzc = radio.value;

              for (var i = 0; i < gridValues.fjs.length; i++) {
                var item = gridValues.fjs[i];

                var se = Math.max(item.bqynsfe - item.jme, 0);
                item.phjmseMax = tools.parseValue(nsrInfo.is2019s && gridValues.fjsJc.bqsfsyxgmyhzc == "Y" ? (se * item.phjzbl / 100) : 0, "float2");
                item.phjmse = item.phjmseMax;
              }

              var jzSum = 0;
              gridValues.fjsJc.jzxqkdmje = tools.parseValue(gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje, "float2");
              var isAlljz = isCjrhAlljz(gridValues);
              for (var i = 0; i < gridValues.fjs.length; i++) {
                var item = gridValues.fjs[i];
                var ynse = Math.max(item.bqynsfe - item.jme - item.phjmse, 0);
                if (gridValues.fjsJc.bqsfsycjrhxqyjzzc == "Y" && (item.zsxmDm == "30203" || item.zsxmDm == "30216")) {
                  var kdme = gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje;
                  var itemkdme = tools.parseValue(kdme * item.sl1 / item.slSum, "float2");
                  item.bqcjrhxqydmje = isAlljz ? ynse : itemkdme;

                  ynse = tools.parseValue(Math.max(ynse - item.bqcjrhxqydmje, 0), "float2");
                } else {
                  item.bqcjrhxqydmje = 0;
                }
                jzSum += item.bqcjrhxqydmje;
                // 自动计算11=5-7-8-9-10
                item.bqybtse = tools.parseValue(ynse - item.bqyjse, "float2");
              }
              gridValues.fjsJc.jzxqkdmje -= jzSum;
            },
            setRadioCjrhjz: function (e) {
              var radio = e.currentTarget;
              this.gridData.fjsJc.bqsfsycjrhxqyjzzc = radio.value;

              this.gridData.fjsJc.dqxztze = this.gridData.fjsJc.bqsfsycjrhxqyjzzc == "Y" ? this.gridData.fjsJc.dqxztzeDef : 0;
              this.gridData.fjsJc.jzxqkdmje = tools.parseValue(this.gridData.fjsJc.dqxztze * this.gridData.fjsJc.jzbl + this.gridData.fjsJc.sqldkdmje, "float2");

              var jzSum = 0;
              var isAlljz = isCjrhAlljz(gridValues);
              for (var i = 0; i < gridValues.fjs.length; i++) {
                var item = gridValues.fjs[i];

                var ynse = Math.max(item.bqynsfe - item.jme - item.phjmse, 0);
                if (gridValues.fjsJc.bqsfsycjrhxqyjzzc == "Y" && (item.zsxmDm == "30203" || item.zsxmDm == "30216")) {
                  var kdme = gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje;
                  var itemkdme = tools.parseValue(kdme * item.sl1 / item.slSum, "float2");
                  item.bqcjrhxqydmje = isAlljz ? ynse : itemkdme;

                  ynse = tools.parseValue(Math.max(ynse - item.bqcjrhxqydmje, 0), "float2");
                } else {
                  item.bqcjrhxqydmje = 0;
                }
                jzSum += item.bqcjrhxqydmje;
                // 自动计算11=5-7-8-9-10
                item.bqybtse = tools.parseValue(ynse - item.bqyjse, "float2");
              }
              gridValues.fjsJc.jzxqkdmje -= jzSum;
            },
            setXztze: function (index) {
              // 设置新增投资额
              var notices = {
                "name": fjsJcInfosCjrh[index].name,
                "cache": "fjs_jc_dqxztze_" + index,
                "label": "附加税费  纳税人信息 - " + fjsJcInfosCjrh[index].title,
                "type": fjsJcInfosCjrh[index].type,
                "index": index
              };

              var defaultValue = this.gridData.fjsJc[notices.name];
              var value = prompt(JSON.stringify(notices), defaultValue);
              if (!!value) {
                var __value__ = JSON.parse(value);

                // 当期新增投资额
                this.gridData.fjsJc[notices.name] = tools.parseValue(__value__.value, notices.type);
                this.gridData.fjsJc.dqxztzeDef = this.gridData.fjsJc.dqxztze;

                this.gridData.fjsJc.jzxqkdmje = tools.parseValue(this.gridData.fjsJc.dqxztze * this.gridData.fjsJc.jzbl + this.gridData.fjsJc.sqldkdmje, "float2");

                var jzSum = 0;
                var isAlljz = isCjrhAlljz(gridValues);
                for (var i = 0; i < gridValues.fjs.length; i++) {
                  var item = gridValues.fjs[i];

                  var ynse = Math.max(item.bqynsfe - item.jme - item.phjmse, 0);
                  if (gridValues.fjsJc.bqsfsycjrhxqyjzzc == "Y" && (item.zsxmDm == "30203" || item.zsxmDm == "30216")) {
                    var kdme = gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje;
                    var itemkdme = tools.parseValue(kdme * item.sl1 / item.slSum, "float2");
                    item.bqcjrhxqydmje = isAlljz ? ynse : itemkdme;

                    ynse = tools.parseValue(Math.max(ynse - item.bqcjrhxqydmje, 0), "float2");
                  } else {
                    item.bqcjrhxqydmje = 0;
                  }
                  jzSum += item.bqcjrhxqydmje;
                  // 自动计算11=5-7-8-9-10
                  item.bqybtse = tools.parseValue(ynse - item.bqyjse, "float2");
                }
                this.gridData.fjsJc.jzxqkdmje -= jzSum;
              }

              var step = 0;
              if ("1" == __value__.flag) {
                step = -1;
              } else if ("2" == __value__.flag) {
                step = 1;
              }
              if (step != 0) {
                var nextIndex = index + step;
                if (nextIndex < 0) {
                  nextIndex = fjsJcInfosCjrh.length - 1;
                }
                if (nextIndex >= fjsJcInfosCjrh.length) {
                  nextIndex = 0;
                }
                this.setXztze(nextIndex);
              }
            },
            setValueH: function (index) {
              var notices = {
                "name": fjsJcInfos[index].name,
                "cache": "fjs_jc_" + index,
                "label": "附加税费  纳税人信息 - " + fjsJcInfos[index].title,
                "type": fjsJcInfos[index].type,
                "index": index
              };

              var defaultValue = this.gridData.fjsJc[notices.name];
              var value = prompt(JSON.stringify(notices), defaultValue);
              if (!!value) {
                var __value__ = JSON.parse(value);

                var v = tools.parseValue(__value__.value, notices.type);
                if (notices.name == "zjhm" && v.indexOf("'") >= 0) {
                  // 身份证件号码不能输入单引号
                  alert("附加税 身份证件号码不能包含英文单引号");
                  return;
                }
                if (notices.name == "lxfs" && v.indexOf("'") >= 0) {
                  // 联系方式不能输入单引号
                  alert("附加税 联系方式不能包含英文单引号");
                  return;
                }

                this.gridData.fjsJc[notices.name] = v;
                if (index == 0) {
                  // 身份证件名称
                  if (__value__.value == "") {
                    this.gridData.fjsJc.sfzjlxMc = "";
                  } else {
                    this.gridData.fjsJc.sfzjlxMc = __value__["value2"];
                  }
                }

                var step = 0;
                if ("1" == __value__.flag) {
                  step = -1;
                } else if ("2" == __value__.flag) {
                  step = 1;
                }
                if (step != 0) {
                  var nextIndex = index + step;
                  if (nextIndex < 0) {
                    nextIndex = fjsJcInfos.length - 1;
                  }
                  if (nextIndex >= fjsJcInfos.length) {
                    nextIndex = 0;
                  }
                  this.setValueH(nextIndex);
                }
              }
            },
            setValue: function (row, index) {
              var item = this.gridData.fjs[row];
              var jzbz = this.nsr.is2019s && this.gridData.fjsJc.bqsfsyxgmyhzc == "Y";
              var infos = item.mz ? (jzbz ? fjsInfosMzZzsjz : fjsInfosMz) : (jzbz ? fjsInfosZzsjz : fjsInfos);

              var notices = {
                "name": infos[index].name,
                "cache": "fjs_" + (row + 1) + "_" + (index + 1),
                "label": item.zsxmMc + " - 第" + infos[index].row + "列、" + infos[index].title,
                "type": infos[index].type,
                "index": index,
                "zsxmDm": item.zsxmDm
              };
              var defaultValue = item[notices.name];
              var value = prompt(JSON.stringify(notices), defaultValue);
              if (!!value) {
                var __value__ = JSON.parse(value);

                if ("bqyjse" == notices.name) {
                  var num = tools.parseValue(__value__.value, notices.type);
                  item[notices.name] = Math.max(item.yjs == undefined ? 0 : tools.parseValue(item.yjs, "float2"), num);
                } else if ("ybzzs" == notices.name) {
                  // 一般增值税修改一行，所有行同时修改
                  // 更正时只能改大，正常申报时可改大改小
                  var result = 0;
                  if ("Y" == this.nsr.gzbz) {
                    var inputValue = tools.parseValue(__value__.value, notices.type);
                    result = Math.max(inputValue, item.ybzzsDefault);

                    if (inputValue < result) {
                      alert("更正申报时，附加税费 - 一般增值税 必须大于等于" + result);
                      return;
                    }
                  } else {
                    result = tools.parseValue(__value__.value, notices.type);
                  }
                  for (var i = 0; i < this.gridData.fjs.length; i++) {
                    this.gridData.fjs[i].ybzzs = result;
                  }
                } else if ("zzsmdse" == notices.name) {
                  // 第二列增值税免抵税额修改一行，所有行同时修改
                  var result = tools.parseValue(__value__.value, notices.type);
                  for (var i = 0; i < this.gridData.fjs.length; i++) {
                    this.gridData.fjs[i].zzsmdse = result;
                  }
                } else if ("phjmse" == notices.name) {
                  // 修改增值税减征额，只能改小
                  var inputValue = tools.parseValue(__value__.value, notices.type);
                  var result = Math.min(inputValue, item.phjmseMax);

                  if (inputValue > item.phjmseMax) {
                    alert("附加税费 - " + notices.label + " 不能大于" + item.phjmseMax + "。");
                    return;
                  }

                  item.phjmse = result;
                } else {
                  item[notices.name] = tools.parseValue(__value__.value, notices.type);
                }

                if (notices.name != "jmxzDm") {
                  // 所有条都修改
                  for (var i = 0; i < this.gridData.fjs.length; i++) {
                    var item = this.gridData.fjs[i];
                    // 自动计算3=1+2
                    item.hj = tools.parseValue(item.ybzzs + item.zzsmdse, "float2");
                    // 自动计算5=3*4
                    item.bqynsfe = tools.parseValue(item.hj * item.sl1, "float2");

                    if (item.mz) {
                      item.jme = item.bqynsfe;

                      var dm = "";
                      switch (item.zsxmDm) {
                        case "30499":
                          dm = "0099129999";
                          break;
                        case "30203":
                          dm = "0061042802";
                          break;
                        case "30216":
                          dm = "0061042802";
                          break;
                      }
                      if (item.bqynsfe > 0) {
                        item.jmxzDm = dm;
                      } else {
                        item.jmxzDm = "";
                      }
                    }

                    var se = Math.max(item.bqynsfe - item.jme, 0);
                    item.phjmseMax = tools.parseValue(jzbz ? (se * item.phjzbl / 100) : 0, "float2");
                    if ("phjmse" != notices.name) {
                      item.phjmse = item.phjmseMax;
                    } else {
                      item.phjmse = Math.min(item.phjmseMax, item.phjmse);
                    }
                  }

                  var jzSum = 0;
                  gridValues.fjsJc.jzxqkdmje = tools.parseValue(gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje, "float2");
                  var isAlljz = isCjrhAlljz(gridValues);
                  for (var i = 0; i < gridValues.fjs.length; i++) {
                    var item = gridValues.fjs[i];
                    var ynse = Math.max(item.bqynsfe - item.jme - item.phjmse, 0);
                    if (gridValues.fjsJc.bqsfsycjrhxqyjzzc == "Y" && (item.zsxmDm == "30203" || item.zsxmDm == "30216")) {
                      var kdme = gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje;
                      var itemkdme = tools.parseValue(kdme * item.sl1 / item.slSum, "float2");
                      item.bqcjrhxqydmje = isAlljz ? ynse : itemkdme;

                      ynse = tools.parseValue(Math.max(ynse - item.bqcjrhxqydmje, 0), "float2");
                    } else {
                      item.bqcjrhxqydmje = 0;
                    }
                    jzSum += item.bqcjrhxqydmje;
                    // 自动计算11=5-7-8-9-10
                    item.bqybtse = tools.parseValue(ynse - item.bqyjse, "float2");
                  }
                  gridValues.fjsJc.jzxqkdmje -= jzSum;
                }

                var step = 0;
                if ("1" == __value__.flag) {
                  step = -1;
                } else if ("2" == __value__.flag) {
                  step = 1;
                }
                if (step != 0) {
                  var nextIndex = index + step;
                  if (nextIndex < 0) {
                    nextIndex = infos.length - 1;
                  }
                  if (nextIndex >= infos.length) {
                    nextIndex = 0;
                  }
                  this.setValue(row, nextIndex);
                }
              }
            }
          }
        });
      }
    })();

    // 记录当前简易申报，增值税前4项选择情况，报表与原生4个勾选状态同步，是否正确在validate中判断
    var zzsCb = {
      hw: {lessQzd: false, wkzp: false},
      fw: {lessQzd: false, wkzp: false}
    };
    return {
      /**
       * 简易申报外部输入
       * @param type      税种
       * @param index     栏次/key
       * @param value     值
       * @param valueEx   增值税服务列的值/证件类型名称
       */
      inputEasy: function (type, index, value, valueEx, callBackName) {
        gridValues.isJysb = true;

        // 输入值是否被校验拦截
        var interrupt = false;
        var interruptMsg = "";

        var hasZzs = whasZzs(nsrInfo) && nsrInfo.zzs.ysbBz != 'Y';
        var hasGs = whasGs(nsrInfo);
        var hasFjs = whasFjs(nsrInfo);

        // 是否需要触发自动计算
        var compute = false;

        var srzeObj = calculateSrzeReal(nsrInfo, gridValues);
        switch (type) {
          case 'zzs':
            // 增值税
            if (!hasZzs) {
              interrupt = true;
              interruptMsg = "当期增值税已申报，无需填写";
              break;
            }
            var inStrs = index.split("-");
            if (inStrs.length != 2) {
              interrupt = true;
              interruptMsg = "输入类型有误(" + index + ")，请确认";
              break;
            }
            var data, item, row, rdxzMc, qzd, sjsr, tmpZzsCb;
            // 字段名转换成增值税行次
            switch (inStrs[1]) {
              case "wdqzdxse":
                inStrs[1] = 11;
                break;
              case "bqyjse":
                inStrs[1] = 23;
                break;
            }
            if (parseInt(inStrs[1])) {
              row = mainTableColumnNames[inStrs[1] - 1];
            }
            if (inStrs[0] == "hw") {
              // 输入货物
              rdxzMc = "货物及劳务";
              if (nsrInfo.zzs.szlbDm == "02") {
                // 没有货物
                interrupt = true;
                interruptMsg = "当期增值税未认定“" + rdxzMc + "”，无法填写相应栏次";
                break;
              }
              tmpZzsCb = zzsCb.hw;
              item = row ? row.bys : {};
              sjsr = srzeObj.hw;
              qzd = nsrInfo.zzs.qzd;
              data = gridValues.bys;
            } else if (inStrs[0] == "fw") {
              // 输入服务
              rdxzMc = "服务、不动产和无形资产";
              if (nsrInfo.zzs.szlbDm == "01") {
                // 没有服务
                interrupt = true;
                interruptMsg = "当期增值税未认定“" + rdxzMc + "”，无法填写相应栏次";
                break;
              }
              tmpZzsCb = zzsCb.fw;
              item = row ? row.bysFw : {};
              sjsr = srzeObj.fw;
              qzd = nsrInfo.zzs.fwqzd;
              data = gridValues.bysFw;
            } else {
              interrupt = true;
              interruptMsg = "输入类型有误(" + index + ")，请确认";
              break;
            }
            if (data) {
              if (inStrs[1] == "sjxseLessThanQzd") {
                // 小于等于起征点选择框
                value = value == "1";
                if (value) {
                  // 想修改成“是”
                  if (sjsr > qzd) {
                    interrupt = true;
                    interruptMsg = "当期增值税 " + rdxzMc + "列 所填实际销售额(1、4、7、9、13栏之和" + sjsr + ") 大于起征点(" + qzd + ")，请先点击增值税“详细报表”进行确认。";
                    break;
                  }
                }
                tmpZzsCb.lessQzd = value;
              } else if (inStrs[1] == "wkzp") {
                // 未开专票选择框
                value = value == "1";
                if (value) {
                  // 想修改成“是”
                  var zpje = data.yzSwdkZyfpBhsXse + data.yzSwdkZyfpBhsXse5;
                  if (zpje > 0) {
                    interrupt = true;
                    interruptMsg = "当期增值税 " + rdxzMc + "列 所填实际销售额(2、5栏之和" + zpje + ") 大于0，请先点击增值税“详细报表”进行确认。";
                    break;
                  }
                }
                tmpZzsCb.wkzp = value;
              } else {
                if (!item.disabled && !item.readonly) {
                  data[row.name] = tools.parseValue(value, "float2");
                  console.info("当期增值税 填入 " + rdxzMc + "列 第" + row.index + "行 " + row.columnName + "- " + data[row.name]);
                  compute = true;
                } else {
                  interrupt = true;
                  interruptMsg = "当期增值税 " + rdxzMc + "列 " + row.columnName + " 不可输入，请确认";
                  break;
                }
              }
            }
            break;
          case 'fjs':
            // 附加税
            if (!hasFjs) {
              interrupt = true;
              interruptMsg = "当期附加税已申报，无需填写";
              break;
            }
            switch (index) {
              case 'lxfs':
                // 联系方式
                gridValues.fjsJc.lxfs = value;
                break;
              case 'sfzjlx':
                // 证件类型
                gridValues.fjsJc.sfzjlx = value;
                gridValues.fjsJc.sfzjlxMc = valueEx;
                break;
              case 'zjhm':
                // 证件号码
                gridValues.fjsJc.zjhm = value;
                break;
            }
            break;
          case 'gs':
            // 个税
            if (!hasGs) {
              interrupt = true;
              interruptMsg = "当期个人所得税已申报，无需填写";
              break;
            }
            if ('srze' == index) {
              // 收入总额
              var srzeMin = calculateSrze(nsrInfo, gridValues, true);
              var inputSrze = tools.parseValue(value, "float2");
              if (inputSrze < srzeMin) {
                interrupt = true;
                var gsHdxse = tools.parseValue(gridValues.grsds.hdsrze, "float2");
                interruptMsg = "个人所得税 - 第4行 收入总额 必须大于等于增值税本期实际销售额与核定销售额的最大值(" + calculateSrze(nsrInfo, gridValues, false) + ")，并且必须大于等于个人所得税核定销售额(" + gsHdxse + "))";
              } else {
                gridValues.grsds.srze = inputSrze;
                console.info("填入 个税 srze - " + gridValues.grsds.srze);
                compute = true;
              }
            }
            break;
        }

        // 返回结果
        var result = {
          "code": 0,  // 0：成功；其他表示失败
          "msg": "",  // 提示消息
          value: {}   // 数据内容，失败时为{}
        };
        if (interrupt) {
          // 输入中断
          console.info("输入被拦截");
          result.code = 1;
          result.msg = interruptMsg;
        } else {
          // 输入未中断，需要自动计算
          if (compute) {
            // 需要自动计算
            console.info("自动计算");
            if (whasZzs(nsrInfo)) {
              // 增值税
              autoCompute('', '', true);
            }
            if (whasGs(nsrInfo)) {
              // 个人所得税
              // 如果当前输入收入总额，取计算和输入的最大值；如果当前不是输入收入总额，取原本值和计算中的最大值(可以改小成计算值)
              gridValues.grsds.srze = Math.max("srze" == index ? value : gridValues.grsds.srze, calculateSrze(nsrInfo, gridValues, true));
              if (nsrInfo.grsds.isSeason) {
                // 季报
                if (gridValues.grsds.srze <= 90000) {
                  gridValues.grsds.hdzsl = 0;
                  gridValues.grsds.zszmDm = "1010602002120044";
                  gridValues.grsds.zszmMc = "季度经营收入在9万元（含）以下的部分";
                } else if (gridValues.grsds.srze <= 150000) {
                  gridValues.grsds.hdzsl = 0.5;
                  gridValues.grsds.zszmDm = "1010602002120045";
                  gridValues.grsds.zszmMc = "季度经营收入在9万元至15万元(含）之间";
                } else if (gridValues.grsds.srze <= 300000) {
                  gridValues.grsds.hdzsl = 0.8;
                  gridValues.grsds.zszmDm = "1010602002120046";
                  gridValues.grsds.zszmMc = "季度经营收入在15万元至30万元（含）之间";
                } else {
                  gridValues.grsds.hdzsl = 1.4;
                  gridValues.grsds.zszmDm = "1010602002120047";
                  gridValues.grsds.zszmMc = "季度经营收入在30万元以上";
                }
              } else {
                // 月报
                if (gridValues.grsds.srze <= 30000) {
                  gridValues.grsds.hdzsl = 0;
                  gridValues.grsds.zszmDm = "1010602002120040";
                  gridValues.grsds.zszmMc = "月度经营收入在3万元（含）以下的部分";
                } else if (gridValues.grsds.srze <= 50000) {
                  gridValues.grsds.hdzsl = 0.5;
                  gridValues.grsds.zszmDm = "1010602002120041";
                  gridValues.grsds.zszmMc = "月度经营收入在3万元至5万元(含）之间";
                } else if (gridValues.grsds.srze <= 100000) {
                  gridValues.grsds.hdzsl = 0.8;
                  gridValues.grsds.zszmDm = "1010602002120042";
                  gridValues.grsds.zszmMc = "月度经营收入在5万元至10万元（含）之间";
                } else {
                  gridValues.grsds.hdzsl = 1.4;
                  gridValues.grsds.zszmDm = "1010602002120043";
                  gridValues.grsds.zszmMc = "月度经营收入在10万元以上";
                }
              }
              gridValues.grsds.ynse = tools.parseValue(Math.max(gridValues.grsds.srze - gridValues.grsds.jcx, 0) * gridValues.grsds.hdzsl / 100, "float2");
              gridValues.grsds.bqybtse = gridValues.grsds.ynse;
            }
            if (whasFjs(nsrInfo)) {
              // 附加税
              if (gridValues.fjs.length > 0) {
                // 修改销售额，更改附加税免征状态
                var xse = calculateSrze(nsrInfo, gridValues, false);
                var qzd = ("08" == nsrInfo.zzs.nsqxDm) ? 300000 : 100000;
                if (gridValues.fjs.length > 0) {
                  for (var i = 0; i < gridValues.fjs.length; i++) {
                    var item = gridValues.fjs[i];
                    // 其他行政事业性收费、教育费、地方教育，如果当期销售额<= 10万（月）或者30万（季），减免性质自动带出，并免征
                    var mz = ("30499" == item.zsxmDm || "30203" == item.zsxmDm || "30216" == item.zsxmDm) && xse <= qzd;
                    item.mz = mz;
                    item.ybzzs = tools.parseValue(Math.max(tools.parseValue(nsrInfo.zzs.xgmYbtse, "float2") + gridValues.bys.ybtSeBq + gridValues.bysFw.ybtSeBq, 0), "float2");

                    // 自动计算3=1+2
                    item.hj = tools.parseValue(item.ybzzs + item.zzsmdse, "float2");
                    // 自动计算5=3*4
                    item.bqynsfe = tools.parseValue(item.hj * item.sl1, "float2");

                    if (item.mz) {
                      item.jme = item.bqynsfe;

                      var dm = "";
                      switch (item.zsxmDm) {
                        case "30499":
                          dm = "0099129999";
                          break;
                        case "30203":
                          dm = "0061042802";
                          break;
                        case "30216":
                          dm = "0061042802";
                          break;
                      }
                      if (item.bqynsfe > 0) {
                        item.jmxzDm = dm;
                      } else {
                        item.jmxzDm = "";
                      }
                    } else {
                      item.jme = 0;
                      item.jmxzDm = "";
                    }

                    var se = Math.max(item.bqynsfe - item.jme, 0);
                    item.phjmseMax = tools.parseValue(nsrInfo.is2019s && gridValues.fjsJc.bqsfsyxgmyhzc == "Y" ? (se * item.phjzbl / 100) : 0, "float2");
                    item.phjmse = item.phjmseMax;
                  }

                  var jzSum = 0;
                  gridValues.fjsJc.jzxqkdmje = tools.parseValue(gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje, "float2");
                  var isAlljz = isCjrhAlljz(gridValues);
                  for (var i = 0; i < gridValues.fjs.length; i++) {
                    var item = gridValues.fjs[i];
                    var ynse = Math.max(item.bqynsfe - item.jme - item.phjmse, 0);
                    if (gridValues.fjsJc.bqsfsycjrhxqyjzzc == "Y" && (item.zsxmDm == "30203" || item.zsxmDm == "30216")) {
                      var kdme = gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje;
                      var itemkdme = tools.parseValue(kdme * item.sl1 / item.slSum, "float2");
                      item.bqcjrhxqydmje = isAlljz ? ynse : itemkdme;

                      ynse = tools.parseValue(Math.max(ynse - item.bqcjrhxqydmje, 0), "float2");
                    } else {
                      item.bqcjrhxqydmje = 0;
                    }
                    jzSum += item.bqcjrhxqydmje;
                    // 自动计算11=5-7-8-9-10
                    item.bqybtse = tools.parseValue(ynse - item.bqyjse, "float2");
                  }
                  gridValues.fjsJc.jzxqkdmje -= jzSum;
                }
              }
            }
          }
        }

        // 计算简易申报报表值
        var easyValue = {};
        if (hasZzs) {
          var zzs = {};
          if (nsrInfo.zzs.szlbDm != "02") {
            // 有货物
            // var sjxseLessThanQzd = srzeObj.hw <= nsrInfo.zzs.qzd;
            // var wkzp = gridValues.bys.yzSwdkZyfpBhsXse + gridValues.bys.yzSwdkZyfpBhsXse5 <= 0;
            var hw = {
              "qzd": tools.parseValue(nsrInfo.zzs.qzd, "float2"),
              "sjxseLessThanQzd": {
                type: "bool",
                visible: true,
                enable: true,
                editable: true,
                value: zzsCb.hw.lessQzd
              },   // 实际销售额小于等于起征点
              "wkzp": {type: "bool", visible: true, enable: true, editable: true, value: zzsCb.hw.wkzp},  // 未开专票
              "wdqzdxse": {
                type: "float2",
                visible: zzsCb.hw.lessQzd || zzsCb.fw.lessQzd,
                enable: zzsCb.hw.lessQzd,
                editable: true,
                value: tools.parseValue(gridValues.bys.msWdqzdXse, "float2")
              },
              "ynsehj": {
                type: "float2",
                visible: true,
                enable: true,
                editable: false,
                value: tools.parseValue(gridValues.bys.ynSeHj, "float2")
              },
              "bqyjse": {
                type: "float2",
                visible: gridValues.bys.yjSeBq > 0 || gridValues.bysFw.yjSeBq > 0,
                enable: true,
                editable: true,
                value: tools.parseValue(gridValues.bys.yjSeBq, "float2")
              },
              "bqybtse": {
                type: "float2",
                visible: true,
                enable: true,
                editable: false,
                value: tools.parseValue(gridValues.bys.ybtSeBq, "float2")
              }
            };
            zzs.hw = hw;
          }
          if (nsrInfo.zzs.szlbDm != "01") {
            // 有服务
            // var sjxseLessThanQzd = srzeObj.fw <= nsrInfo.zzs.fwqzd;
            // var wkzp = gridValues.bysFw.yzSwdkZyfpBhsXse + gridValues.bysFw.yzSwdkZyfpBhsXse5 <= 0;
            var fw = {
              "qzd": tools.parseValue(nsrInfo.zzs.fwqzd, "float2"),
              "sjxseLessThanQzd": {
                type: "bool",
                visible: true,
                enable: true,
                editable: true,
                value: zzsCb.fw.lessQzd
              },   // 实际销售额小于等于起征点
              "wkzp": {type: "bool", visible: true, enable: true, editable: true, value: zzsCb.fw.wkzp},  // 未开专票
              "wdqzdxse": {
                type: "float2",
                visible: zzsCb.hw.lessQzd || zzsCb.fw.lessQzd,
                enable: zzsCb.fw.lessQzd,
                editable: true,
                value: tools.parseValue(gridValues.bysFw.msWdqzdXse, "float2")
              },
              "ynsehj": {
                type: "float2",
                visible: true,
                enable: true,
                editable: false,
                value: tools.parseValue(gridValues.bysFw.ynSeHj, "float2")
              },
              "bqyjse": {
                type: "float2",
                visible: gridValues.bys.yjSeBq > 0 || gridValues.bysFw.yjSeBq > 0,
                enable: true,
                editable: true,
                value: tools.parseValue(gridValues.bysFw.yjSeBq, "float2")
              },
              "bqybtse": {
                type: "float2",
                visible: true,
                enable: true,
                editable: false,
                value: tools.parseValue(gridValues.bysFw.ybtSeBq, "float2")
              }
            };
            zzs.fw = fw;
          }
          if (zzs) {
            easyValue.zzs = zzs;
          }
        }
        if (hasGs) {
          var gs = {
            "srze": {
              type: "float2",
              visible: true,
              enable: true,
              editable: true,
              value: tools.parseValue(gridValues.grsds.srze, "float2")
            },
            "bqybtse": {
              type: "float2",
              visible: true,
              enable: true,
              editable: false,
              value: tools.parseValue(gridValues.grsds.bqybtse, "float2")
            }
          };
          easyValue.gs = gs;
        }
        if (hasFjs) {
          var sum = 0;
          for (var i = 0; i < gridValues.fjs.length; i++) {
            sum += gridValues.fjs[i].bqybtse;
          }
          var fjs = {
            "lxfs": {
              type: "str(30)",
              visible: nsrInfo.fjs.lxfs.length <= 0,
              enable: true,
              editable: true,
              value: gridValues.fjsJc.lxfs
            },
            "sfzjlx": {
              type: "sfzjlx",
              visible: nsrInfo.fjs.sfzjLx.length <= 0,
              enable: true,
              editable: true,
              value: gridValues.fjsJc.sfzjlx,
              mc: gridValues.fjsJc.sfzjlxMc
            },
            "sfzjhm": {
              type: "str(30)",
              visible: nsrInfo.fjs.zjhm.length <= 0,
              enable: true,
              editable: true,
              value: gridValues.fjsJc.zjhm
            },
            "bqybtse": {
              type: "float2",
              visible: true,
              enable: true,
              editable: false,
              value: tools.parseValue(sum, "float2")
            }
          };
          easyValue.fjs = fjs;
        }
        result.value = easyValue;

        var reResult = JSON.stringify(result);
        if (callBackName) {
          if (typeof callBackName == "function") {
            callBackName(reResult);
          } else {
            (new Function(callBackName + " (JSON.stringify(" + reResult + "));"))()
          }
        } else {
          if (window.webkit) {
            window.webkit.messageHandlers.iosInputEasyCallback.postMessage(reResult);
          }
        }
      },
      /**
       * 写入不动产销售额
       */
      inputBdcxse: function (bdcxse) {
        gridValues.bysFw.bdcxse = tools.parseValue(bdcxse, "float2");
      },
      /**
       * 申报成功
       * @param type 税种
       */
      loadSuc: function (type) {
        if ('zzs' == type) {
          nsrInfo.zzs.ysbBz = "Y";
        } else if ('gs' == type && nsrInfo.grsds != undefined) {
          nsrInfo.grsds.ysbBz = "Y";
        } else if ('fjs' == type && nsrInfo.fjs != undefined) {
          nsrInfo.fjs.fjsYsbBz = "Y";
        }

        if (whasZzs(nsrInfo)) {
          // 显示增值税
          showBb('zzs');
        } else {
          if (whasFjs(nsrInfo)) {
            // 显示附加税
            showBb('fjs');
          } else {
            if (whasGs(nsrInfo)) {
              // 还有个税
              showBb('gs')
            } else {
              // 都申报完了
              showBb('zzs');
            }
          }
        }
        if (gridValues.isJysb) {
          if (gridValues.isAndroid) {
            getEasyTableValues('window.jsTransferShenBao.getEasyTableValues');
          } else {
            getEasyTableValues();
          }
        }
      },
      /**
       * 获取报表数据
       * @param callBackName  回调方法名
       */
      getValues: function (callBackName) {
        // 增值税2019年减征计算
        if (nsrInfo.is2019s) {
          gridValues.bqxseHj = calculateSrze(nsrInfo, gridValues, false);
        }

        // 个人所得税计费依据
        gridValues.grsds.jfyj = tools.parseValue(gridValues.grsds.srze - gridValues.grsds.jcx, "float2");

        // 附加税申报时10109城建税必须在第一个
        var fjsArr = gridValues["fjs"];
        if (fjsArr.length > 0) {
          gridValues["fjs"] = gridValues["fjs"].sort(tools.sortBy("zsxmDm", true));
        }

        var resultValues = JSON.stringify(gridValues);
        var json = JSON.parse(resultValues);
        if ("Y" == nsrInfo.gzbz) {
          // 更正情况下，去掉更正数据
          json.fjsgz = {};
          json.grsdsgz = {};
        }
        if (json.fjsJc.bqsfsycjrhxqyjzzc == "Y") {
          json.fjsJc.dqxzktme = tools.parseValue(json.fjsJc.dqxztze * json.fjsJc.jzbl, "float2");
        }
        // 增加附加税小规模减征数据
        var fjsItemArr = json["fjs"];
        for (var i = 0; i < fjsItemArr.length; i++) {
          var item = fjsItemArr[i];
          item.bqsfsyxgmyhzc = json.fjsJc.bqsfsyxgmyhzc;
          var xzDm = "";
          var sxDm = "";
          if (nsrInfo.is2019s) {
            switch (item.zsxmDm) {
              case "10109":
                // 城建税
                xzDm = "0007049901";
                sxDm = "SXA031900988";
                break;
              case "30203":
                // 教育
                xzDm = "0061049901";
                sxDm = "SXA031900993";
                break;
              case "30216":
                // 地方教育
                xzDm = "0099049901";
                sxDm = "SXA031900994";
                break;
            }
          }
          switch (item.zsxmDm) {
            case "30203":
              // 教育
              item.cjrhjmxzDm = json.fjsJc.bqsfsycjrhxqyjzzc == "Y" && item.bqcjrhxqydmje > 0 ? "0061101402" : "";
              item.cjrhjmswsxDm = json.fjsJc.bqsfsycjrhxqyjzzc == "Y" && item.bqcjrhxqydmje > 0 ? "SXA031901065" : "";
              break;
            case "30216":
              // 地方教育
              item.cjrhjmxzDm = json.fjsJc.bqsfsycjrhxqyjzzc == "Y" && item.bqcjrhxqydmje > 0 ? "0099101401" : "";
              item.cjrhjmswsxDm = json.fjsJc.bqsfsycjrhxqyjzzc == "Y" && item.bqcjrhxqydmje > 0 ? "SXA031901066" : "";
              break;
          }
          item.phjmxzDm = xzDm;   // 减免性质代码
          item.phjmswsxDm = sxDm; // 减免事项代码
        }

        resultValues = JSON.stringify(json);

        if (callBackName != undefined) {
          if (typeof callBackName == "function") {
            callBackName(resultValues);
          } else {
            (new Function(callBackName + " (JSON.stringify(" + resultValues + "));"))()
          }
        } else {
          if (window.webkit) {
            window.webkit.messageHandlers.iosTalbeAllValuesCallback.postMessage(resultValues);
          }
        }
      },
      /**
       * 本地校验
       * @param type  税种
       * @param callBackName  回调
       */
      validate: function (type, callBackName) {
        var VALIDATE_SIGN = {
          "success": 0,
          "error": 1,
          "warning": 2
        };
        var validateSign = VALIDATE_SIGN.success;
        var message = [];

        /**
         * 约等于
         *
         * @param {Object} left 等式左边的值
         * @param {Object} right 等式右边的值
         * @param {Object} errorRange 误差范围
         */
        var approximate = function (left, right, errorRange) {
          var dValue = tools.parseValue(Math.abs(left - right), "float2");
          var eRange = tools.parseValue(Math.abs(errorRange), "float2");
          return dValue <= eRange;
        };

        // 强制校验
        (function () {
          var addError = function (errorMessage) {
            validateSign = VALIDATE_SIGN.error;
            message.push("（强制校验）" + errorMessage);
          };

          if (type.indexOf("zzs") >= 0) {
            // 有增值税
            // 简易申报校验
            if (gridValues.isJysb) {
              // 简易申报校验
              var srzeJy = calculateSrzeReal(nsrInfo, gridValues);
              if (nsrInfo.zzs.szlbDm != "02") {
                // 货物
                if (zzsCb.hw.lessQzd && srzeJy.hw > nsrInfo.zzs.qzd) {
                  // 实际销售额大于起征点，不应该勾选
                  addError("增值税(简易) 货物及劳务 本期实际销售额(" + srzeJy.hw + ")大于起征点(" + nsrInfo.zzs.qzd + ")，“本期销售额是否小于等于起征点”不应该勾选。");
                }
                if (!zzsCb.hw.lessQzd && srzeJy.hw <= nsrInfo.zzs.qzd) {
                  // 实际销售额小于起征点起征点，应该勾选
                  addError("增值税(简易) 货物及劳务 本期实际销售额(" + srzeJy.hw + ")小于等于起征点(" + nsrInfo.zzs.qzd + ")，“本期销售额是否小于等于起征点”应该勾选。");
                }
                var zp = gridValues.bys.yzSwdkZyfpBhsXse + gridValues.bys.yzSwdkZyfpBhsXse5;
                if (zzsCb.hw.wkzp && zp > 0) {
                  // 开了专票，不应该勾选
                  addError("增值税(简易) 货物及劳务 本期税务机关代开的增值税专用发票不含税销售额(" + zp + ")大于0，“是否未开专票”不应该勾选。");
                }
                if (!zzsCb.hw.wkzp && zp == 0) {
                  // 没开专票，应该勾选
                  addError("增值税(简易) 货物及劳务 本期税务机关代开的增值税专用发票不含税销售额(" + zp + ")等于0，“是否未开专票”应该勾选。");
                }
              }
              if (nsrInfo.zzs.szlbDm != "01") {
                // 服务
                if (zzsCb.fw.lessQzd && srzeJy.fw > nsrInfo.zzs.fwqzd) {
                  // 实际销售额大于起征点，不应该勾选
                  addError("增值税(简易) 服务、不动产和无形资产 本期实际销售额(" + srzeJy.hw + ")大于起征点(" + nsrInfo.zzs.qzd + ")，“本期销售额是否小于等于起征点”不应该勾选。");
                }
                if (!zzsCb.fw.lessQzd && srzeJy.fw <= nsrInfo.zzs.fwqzd) {
                  // 实际销售额小于起征点起征点，应该勾选
                  addError("增值税(简易) 服务、不动产和无形资产 本期实际销售额(" + srzeJy.hw + ")小于等于起征点(" + nsrInfo.zzs.qzd + ")，“本期销售额是否小于等于起征点”应该勾选。");
                }
                var zp = gridValues.bysFw.yzSwdkZyfpBhsXse + gridValues.bysFw.yzSwdkZyfpBhsXse5;
                if (zzsCb.fw.wkzp && zp > 0) {
                  // 开了专票，不应该勾选
                  addError("增值税(简易) 服务、不动产和无形资产 本期税务机关代开的增值税专用发票不含税销售额(" + zp + ")大于0，“是否未开专票”不应该勾选。");
                }
                if (!zzsCb.fw.wkzp && zp == 0) {
                  // 没开专票，应该勾选
                  addError("增值税(简易) 服务、不动产和无形资产 本期税务机关代开的增值税专用发票不含税销售额(" + zp + ")等于0，“是否未开专票”应该勾选。");
                }
              }
            }

            var isXw2019 = false;
            var bdcError = false;
            if (nsrInfo.is2019s) {
              var xse14 = tools.parseValue(gridValues.bys.yzBhsXse + gridValues.bys.yzBhsXse5 + gridValues.bysFw.yzBhsXse + gridValues.bysFw.yzBhsXse5, "float2");

              // 2019新小微标准：不是逾期未认定，且实际销售额-不动产销售额 <= 起征点
              isXw2019 = nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y" && (calculateSrzeReal(nsrInfo, gridValues).value - gridValues.bysFw.bdcxse <= nsrInfo.zzs.qzd);
              if (gridValues.bysFw.bdcxse > xse14) {
                // 销售额1、4行合计必须大于等于不动产销售额
                addError("增值税  主表1、4行合计(" + xse14 + ")应该大于等于不动产销售额(" + gridValues.bysFw.bdcxse + ")")
                bdcError = true;
              }
            }

            if (nsrInfo.zzs.szlbDm != "02") {
              // 应税货物及劳务校验
              // 小微标准
              // 1）非逾期未认定企业
              // 2）第1、7、9、13栏次的“货物及劳务”列 “本期数”合计金额小于等于“小规模企业应税货物起征点”
              var __cache__ = "bys";
              var isXwqy = nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y" && // 非逾期未认定
                (getValue(__cache__, 1) + getValue(__cache__, 7) + getValue(__cache__, 9) + getValue(__cache__, 13) <= nsrInfo.zzs.qzd);
              if (nsrInfo.is2019s) {
                isXwqy = isXw2019;
              }
              // 1.（强制）第1行、第4行、第7行、第10行、第11行、第12行、第13行、第18行、第23行均不得为负数
              var noMinus = [1, 4, 7, 10, 11, 12, 13, 18, 23];
              for (var i = 0; i < noMinus.length; i++) {
                var v = getValue(__cache__, noMinus[i]);
                if (v < 0) {
                  addError("“" + alias.bys[noMinus[i]].label + "”应该大于等于 0！");
                }
              }

              // 2.（强制）第7行≥第8行
              if (getValue(__cache__, 7) < getValue(__cache__, 8)) {
                addError("“" + alias.bys[7].label + "”应该大于等于“" + alias.bys[8].label + "”！");
              }
              // 3.（强制）第9行=第10行+第11行+第12行
              if (!approximate(getValue(__cache__, 9), getValue(__cache__, 10) + getValue(__cache__, 11) + getValue(__cache__, 12), 1)) {
                addError("“" + alias.bys[9].label + "”应该等于“" + alias.bys[10].label + "”、“" + alias.bys[11].label + "”和“" + alias.bys[12].label + "”之和！");
              }
              // 5.（强制）第13行≥第14行
              if (getValue(__cache__, 13) < getValue(__cache__, 14)) {
                addError("“" + alias.bys[13].label + "”应该大于等于“" + alias.bys[14].label + "”！");
              }
              // 7.（强制）第18行≤第16行
//                            if (getValue(__cache__, 18) > getValue(__cache__, 16)) {
//                                addError("“" + alias.bys[18].label + "”应该小于等于“" + alias.bys[16].label + "”！");
//                            }
              // 8.（强制）第9、10、11栏有数，第19、20、21行，则不能为零
//                            if (!(getValue(__cache__, 9) != 0 && getValue(__cache__, 19) == 0 && getValue(__cache__, 11) != 0 && getValue(__cache__, 21) == 0)) {
//                                // 检验9-19和校验11-21同时满足时，该校验可以不要
//                                if ((Math.abs(getValue(__cache__, 9)) + Math.abs(getValue(__cache__, 10)) + Math.abs(getValue(__cache__, 11))) != 0 &&
//                                    (Math.abs(getValue(__cache__, 19)) + Math.abs(getValue(__cache__, 20)) + Math.abs(getValue(__cache__, 21))) == 0) {
//                                    addError("您填写了“" + alias.bys[9].label + "”、“" + alias.bys[10].label + "”和“" + alias.bys[11].label + "”，“" + alias.bys[19].label + "”、“" + alias.bys[20].label + "”和“" + alias.bys[21].label + "”不能为0！");
//                                }
//                            }
              // 9.（强制）第22行=第16行-第18行
              if (!approximate(getValue(__cache__, 22), Math.max(getValue(__cache__, 16), getValue(__cache__, 17)) - getValue(__cache__, 18), 1)) {
                addError("“" + alias.bys[22].label + "”应该等于“" + alias.bys[16].label + "”减去“" + alias.bys[18].label + "”或者“" + alias.bys[17].label + "”减去“" + alias.bys[18].label + "”！");
              }
              // 10.（强制）第24行=第22行-第23行
              if (!approximate(getValue(__cache__, 24), getValue(__cache__, 22) - getValue(__cache__, 23), 1)) {
                addError("“" + alias.bys[24].label + "”应该等于“" + alias.bys[22].label + "”减去“" + alias.bys[23].label + "”！");
              }
              if (!bdcError) {
                /*
                                 4、第10栏
                                 （1）条件：起征点不等于0，并且纳税人不满足小微企业
                                 校验：已超过小微标准，“第10行_本期数_货物及劳务”不应有数据!! （客户端强制校验）

                                 （2）条件：起征点等于0，并且纳税人不满足小微企业
                                 校验：本企业应税货物起征点为0，不能享受小微企业暂免征收增值税政策，“第10行_本期数_货物及劳务”不应有数据!!（客户端强制校验）
                                 */
                if (!isXwqy) {
                  if (getValue(__cache__, 10) != 0) {
                    if (nsrInfo.zzs.qzd != 0) {
                      addError("本企业不属于小微企业，“" + alias.bys[10].label + "”不应有数据！")
                    } else {
                      addError("本企业应税货物起征点为0，不能享受小微企业暂免征收增值税征政策，“" + alias.bys[10].label + "”不应有数据！")
                    }
                  }
                }
                /*5、第11栏
                                 （1）条件：纳税人不满足小微企业
                                 校验：已超过小微标准，“第11行本期数货物及劳务”不应有数据!!
                                 */
                if (!isXwqy && getValue(__cache__, 11) != 0) {
                  addError("本企业不属于小微企业，“" + alias.bys[11].label + "”不应有数据！");
                }
              }
              /*
                             条件：逾期未认定标志为Y
                             校验：当逾期未认定的一般纳税人标志为Y时，"第16行_第1列"="第1行_第1列"+"第7行_第1列"*最高税率（13%~17%）!!
                             */
              if (nsrInfo.zzs.yqwrdybrBz.toUpperCase() == "Y") {
                if (tools.parseValue((0.13 * (getValue(__cache__, 1) + getValue(__cache__, 7)) - 1), "float2") > getValue(__cache__, 16) || getValue(__cache__, 16) > tools.parseValue((0.17 * (getValue(__cache__, 1) + getValue(__cache__, 7)) + 1), "float2")) {
                  addError("本企业逾期未认定一般纳税人，“" + alias.bys[16].label + "”应该等于“" + alias.bys[1].label + "”加上“" + alias.bys[7].label + "”乘以最高税率，税率范围（13% ~ 17%）！");
                }
              }
              /*
                             条件：逾期未认定标志为N
                             "第16行_第1列"应="第1行_第1列"*3%+"第7行_第1列"*3%,,允许有一元钱误差!!
                             */
              if (nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y") {
                if (!approximate(getValue(__cache__, 16), (tools.parseValue((getValue(__cache__, 1) + getValue(__cache__, 7)) * 0.03, "float2")), 1)) {
                  addError("“" + alias.bys[16].label + "”应该等于“" + alias.bys[1].label + "”加上“" + alias.bys[7].label + "”乘以税率，税率范围（3%）！");
                }
              }
              // 校验：“第19行_第1列”应=“第9行_第1列”*%3，允许有一元钱误差!!
              if (!approximate(getValue(__cache__, 19), tools.parseValue(getValue(__cache__, 9) * 0.03, "float2"), 1)) {
                addError("“" + alias.bys[19].label + "”应该等于“" + alias.bys[9].label + "”乘以税率，税率范围（3%）！");
              }
              // 校验： “第20行_第1列”应=“第10行_第1列”*%3，允许有一元钱误差!!
              if (!approximate(getValue(__cache__, 20), tools.parseValue(getValue(__cache__, 10) * 0.03, "float2"), 1)) {
                addError("“" + alias.bys[20].label + "”应该等于“" + alias.bys[10].label + "”乘以税率，税率范围（3%）！");
              }
              /*
                             “第10行_本期数_货物及劳务”＝0
                             “第10行_本期数_货物及劳务”＝0，则“第20行_本期数_货物及劳务”应＝0!!
                             */
              if (getValue(__cache__, 10) == 0 && getValue(__cache__, 20) != 0) {
                addError("“" + alias.bys[10].label + "”等于0，则“" + alias.bys[20].label + "”也应该等于0！");
              }
              /*
                             “第11行_第1列”<> 0
                             “第21行_第1列”应=“第11行_第1列”*%3，允许有一元钱误差!!
                             */
              if (getValue(__cache__, 21) != 0 && !approximate(getValue(__cache__, 21), tools.parseValue(getValue(__cache__, 11) * 0.03, "float2"), 1)) {
                addError("“" + alias.bys[21].label + "”应该等于“" + alias.bys[11].label + "”乘以税率，税率范围（3%）！");
              }
              /*
                             条件：“第11行_本期数_货物及劳务”=0
                             校验：“第11行_本期数_货物及劳务”=0，则“第21行_本期数_货物及劳务”应=0!!
                             */
              if (getValue(__cache__, 11) == 0 && getValue(__cache__, 21) != 0) {
                addError("“" + alias.bys[11].label + "”等于0，则“" + alias.bys[21].label + "”也应该等于0！");
              }

              /*
                             校验9-19
                             条件：“第9行_本期数_货物及劳务”<>0
                             校验：“第9行_本期数_货物及劳务”<>0，则“第19行_本期数_货物及劳务”应<>0!!
                             */
              if (getValue(__cache__, 9) != 0 && getValue(__cache__, 19) == 0) {
                addError("“" + alias.bys[9].label + "”不等于0，则“" + alias.bys[19].label + "”不应该等于0！");
              }

              /*
                             校验11-21
                             条件：“第11行_本期数_货物及劳务”<>0
                             校验：“第11行_本期数_货物及劳务”<>0，则“第21行_本期数_货物及劳务”应<>0!!
                             */
              if (getValue(__cache__, 11) != 0 && getValue(__cache__, 21) == 0) {
                addError("“" + alias.bys[11].label + "”不等于0，则“" + alias.bys[21].label + "”不应该等于0！");
              }
            }
            /*-------------------------------------------*/
            if (nsrInfo.zzs.szlbDm != "01") {
              // 服务、不动产和无形资产校验
              // 小微标准
              // （1）本列4、5、6栏全部为0时，无需申报附列资料的企业，主表第1、9、13栏次的“服务、不动产和无形资产”列 “本期数”合计金额小于等于“小规模企业应税服物起征点”
              // （3）非逾期未认定企业
              var __cache__ = "bysFw";
              var isXwqy = nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y" && // 非逾期未认定
                (getValue(__cache__, 1) + getValue(__cache__, 9) + getValue(__cache__, 13) <= nsrInfo.zzs.fwqzd) && // 1, 9, 13 未达起征点
                (getValue(__cache__, 4) == 0 && getValue(__cache__, 5) == 0 && getValue(__cache__, 6) == 0);
              if (nsrInfo.is2019s) {
                isXwqy = isXw2019;
              }
              var isOther = getValue(__cache__, 4) != 0 || getValue(__cache__, 5) != 0 || getValue(__cache__, 6) != 0;
              // 1.（强制）第1行、第4行、第7行、第10行、第11行、第12行、第13行、第18行、第23行均不得为负数
              var noMinus = [1, 4, 7, 10, 11, 12, 13, 18, 23];
              for (var i = 0; i < noMinus.length; i++) {
                var v = getValue(__cache__, noMinus[i]);
                if (v < 0) {
                  addError("“" + alias.bysFw[noMinus[i]].label + "”应该大于等于 0！");
                }
              }
              // 2.（强制）第7行≥第8行
              if (getValue(__cache__, 7) < getValue(__cache__, 8)) {
                addError("“" + alias.bysFw[7].label + "”应该大于等于“" + alias.bysFw[8].label + "”！");
              }
              // 3.（强制）第9行=第10行+第11行+第12行
              if (!approximate(getValue(__cache__, 9), getValue(__cache__, 10) + getValue(__cache__, 11) + getValue(__cache__, 12), 1)) {
                addError("“" + alias.bysFw[9].label + "”应该等于“" + alias.bysFw[10].label + "”、“" + alias.bysFw[11].label + "”和“" + alias.bysFw[12].label + "”之和！");
              }
              // 5.（强制）第13行≥第14行
              if (getValue(__cache__, 13) < getValue(__cache__, 14)) {
                addError("“" + alias.bysFw[13].label + "”应该大于等于“" + alias.bysFw[14].label + "”！");
              }
              // 7.（强制）第18行≤第16行
//                            if (getValue(__cache__, 18) > getValue(__cache__, 16)) {
//                                addError("“" + alias.bysFw[18].label + "”应该小于等于“" + alias.bysFw[16].label + "”！");
//                            }
              // 8.（强制）第9、10、11栏有数，第19、20、21行，则不能为零
//                            if (!(getValue(__cache__, 9) != 0 && getValue(__cache__, 19) == 0 && getValue(__cache__, 11) != 0 && getValue(__cache__, 21) == 0)) {
//                                if ((getValue(__cache__, 9) + getValue(__cache__, 10) + getValue(__cache__, 11)) != 0 && (getValue(__cache__, 19) + getValue(__cache__, 20) + getValue(__cache__, 21)) == 0) {
//                                    addError("您填写了“" + alias.bysFw[9].label + "”、“" + alias.bysFw[10].label + "”和“" + alias.bysFw[11].label + "”，“" + alias.bysFw[19].label + "”、“" + alias.bysFw[20].label + "”和“" + alias.bysFw[21].label + "”不能为0！");
//                                }
//                            }
              // 9.（强制）第22行=第16行-第18行
              if (!approximate(getValue(__cache__, 22), Math.max(getValue(__cache__, 16), getValue(__cache__, 17)) - getValue(__cache__, 18), 1)) {
                addError("“" + alias.bysFw[22].label + "”应该等于“" + alias.bysFw[16].label + "”减去“" + alias.bysFw[18].label + "”或者“" + alias.bysFw[17].label + "”减去“" + alias.bysFw[18].label + "”！");
              }
              // 10.（强制）第24行=第22行-第23行
              if (!approximate(getValue(__cache__, 24), getValue(__cache__, 22) - getValue(__cache__, 23), 1)) {
                addError("“" + alias.bysFw[24].label + "”应该等于“" + alias.bysFw[22].label + "”减去“" + alias.bysFw[23].label + "”！");
              }
              if (!bdcError) {
                /*7、第10栏
                                 （1）条件：起征点不等于0，并且纳税人不满足小微企业
                                 校验：已超过小微标准，“第10行_本期数_服务、不动产和无形资产”不应有数据!!（客户端强制校验）
                                 （2）条件：起征点等于0，并且纳税人不满足小微企业
                                 校验：本企业应税服务起征点为0，不能享受小微企业暂免征收增值税政策，“第10行_本期数_服务、不动产和无形资产”不应有数据!!（客户端强制校验）
                                 */
                if (!isXwqy && !isOther) {
                  if (getValue(__cache__, 10) != 0) {
                    if (nsrInfo.zzs.fwqzd != 0) {
                      addError("本企业不属于小微企业，“" + alias.bysFw[10].label + "”不应有数据！")
                    } else {
                      addError("本企业应税货物起征点为0，不能享受小微企业暂免征收增值税征政策，“" + alias.bysFw[10].label + "”不应有数据！")
                    }
                  }
                }
                /*
                                 8、第11栏
                                 （1）条件：纳税人不满足小微企业
                                 校验：已超过小微标准，“第11行_本期数_服务、不动产和无形资产”不应有数据!!
                                 */
                if (!isOther && !isXwqy && getValue(__cache__, 11) != 0) {
                  addError("本企业不属于小微企业，“" + alias.bysFw[11].label + "”不应有数据！");
                }
              }
              /*
                             9、第16行
                             条件：逾期未认定企业标志是N
                             校验： "第16行_第2列"应="第1行_第2列"*0.03+"第4行_第2列"*0.05，自动计算可修改，允许有一元钱误差!!
                             */
              if (nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y") {
                if (!approximate(getValue(__cache__, 16), tools.parseValue(getValue(__cache__, 1) * 0.03 + getValue(__cache__, 4) * 0.05, "float2"), 1)) {
                  addError("“" + alias.bysFw[16].label + "”应该等于“" + alias.bysFw[1].label + "”乘以税率（3%）加上“" + alias.bysFw[4].label + "”乘以税率（5%）！");
                }
              }
              /*
                             10、第16行
                             条件：逾期未认定企业标志是Y
                             校验：当逾期未认定的一般纳税人标志为Y时，"第16行_第2列"="第1行_第2列"*最高税率（6%~17%）+"第4行_第2列"*最高税率（6%~17%）!!
                             即：第（1+4）*17%≥第16行≥第（1+4）*6%（客户端强制）
                             */
              if (nsrInfo.zzs.yqwrdybrBz.toUpperCase() == "Y") {
                if ((tools.parseValue(0.06 * (getValue(__cache__, 1) + getValue(__cache__, 4)), "float2") - 1) > getValue(__cache__, 16) || getValue(__cache__, 16) > (tools.parseValue(0.17 * (getValue(__cache__, 1) + getValue(__cache__, 4)), "float2") + 1)) {
                  addError("本企业逾期未认定一般纳税人，“" + alias.bysFw[16].label + "”应该等于“" + alias.bysFw[1].label + "”加上“" + alias.bysFw[4].label + "”乘以最高税率，税率范围（6% ~ 17%）！");
                }
              }
              /*
                             11、第19行
                             （1）
                             条件：无
                             校验：第19栏“本期免税额”：填写符合免征增值税政策的免税额，免税额根据第9栏“免税销售额”和征收率计算（3%~5%），允许有一元钱误差!!
                             （2）
                             条件：“第9行_本期数_服务、不动产和无形资产”≠0
                             校验：“第9行_本期数_服务、不动产和无形资产”≠0，则“第19行_本期数_服务、不动产和无形资产”应≠0!!
                             */
              if (getValue(__cache__, 9) != 0) {
                if ((tools.parseValue(0.03 * getValue(__cache__, 9), "float2") - 1) > getValue(__cache__, 19) || getValue(__cache__, 19) > (tools.parseValue(0.05 * getValue(__cache__, 9), "float2") + 1)) {
                  addError("“" + alias.bysFw[19].label + "”：请填写符合免征增值税政策的免税额，免税额根据“" + alias.bysFw[9].label + "”和征收税率计算，税率范围（3% ~ 5%）");
                }
                if (getValue(__cache__, 19) == 0) {
                  addError("“" + alias.bysFw[9].label + "”不等于0，则“" + alias.bysFw[19].label + "”不应该等于0！");
                }
              }
              /*
                             12、第20行
                             （1）
                             条件：“第10行_本期数_服务、不动产和无形资产”≠0
                             校验：“第10行_本期数_服务、不动产和无形资产”≠0，则“第20行_本期数_服务、不动产和无形资产”应≠0!! （客户端强制）
                             （2）
                             条件：“第10行_本期数_服务、不动产和无形资产”＝0
                             校验：“第10行_本期数_服务、不动产和无形资产”＝0，则“第20行_本期数_服务、不动产和无形资产”应＝0!! （客户端强制）
                             （3）
                             条件：无
                             校验：第20栏“小微企业免税额”：填写符合小微企业免征增值税政策的增值税免税额，免税额根据第10栏“小微企业免税销售额”和征收率计算（3%~5%），允许有一元钱误差!!
                             */
              if (getValue(__cache__, 10) != 0) {
                if ((tools.parseValue(0.03 * getValue(__cache__, 10), "float2") - 1) > getValue(__cache__, 20) || getValue(__cache__, 20) > (tools.parseValue(0.05 * getValue(__cache__, 10), "float2") + 1)) {
                  addError("“" + alias.bysFw[20].label + "”：填写符合小微企业免征增值税政策的增值税免税额，免税额根据“" + alias.bysFw[10].label + "”和征收税率计算，税率范围（3% ~ 5%）");
                }
                if (getValue(__cache__, 20) == 0) {
                  addError("“" + alias.bysFw[10].label + "”不等于0，则“" + alias.bysFw[20].label + "”不应该等于0！");
                }
              } else if (getValue(__cache__, 20) != 0) {
                addError("“" + alias.bysFw[10].label + "”等于0，则“" + alias.bysFw[20].label + "”应该等于0！");
              }
              /*
                             13、第21行
                             （1）
                             条件：“第11行_本期数_服务、不动产和无形资产”≠0
                             校验：“第11行_本期数_服务、不动产和无形资产”≠0，则“第21行_本期数_服务、不动产和无形资产”应≠0!!
                             （2）
                             条件：“第11行_本期数_服务、不动产和无形资产”＝0
                             校验：“第11行_本期数_服务、不动产和无形资产”＝0，则“第21行_本期数_服务、不动产和无形资产”应＝0!!
                             （3）
                             条件：无
                             校验：第21栏“未达起征点免税额”：填写个体工商户和其他个人未达起征点（含支持小微企业免征增值税政策）的增值税免税额，免税额根据第11栏“未达起征点销售额”和征收率计算（3%~5%），允许有一元钱误差!!
                             */
              if (getValue(__cache__, 11) != 0) {
                var flag = (tools.parseValue(0.03 * getValue(__cache__, 11), "float2") - 1) > getValue(__cache__, 21) || getValue(__cache__, 21) > (tools.parseValue(0.05 * getValue(__cache__, 11), "float2") + 1);
                if (flag) {
                  addError("“" + alias.bysFw[21].label + "”：填写个体工商户和其他个人未达起征点（含支持小微企业免征增值税政策）的增值税免税额，免税额根据“" + alias.bysFw[11].label + "”和征收税率计算，税率范围（3% ~ 5%）");
                }
                if (getValue(__cache__, 21) == 0) {
                  addError("“" + alias.bysFw[11].label + "”不等于0，则“" + alias.bysFw[21].label + "”不应该等于0！");
                }
              } else if (getValue(__cache__, 21) != 0) {
                addError("“" + alias.bysFw[11].label + "”等于0，则“" + alias.bysFw[21].label + "”应该等于0！");
              }
            }

            // 减税校验
            if (gridValues.jsmxb.length > 0) {
              for (var i = 0; i < gridValues.jsmxb.length; i++) {
                var item = gridValues.jsmxb[i];

                if ((
                  (gridValues.jsmxb.length > 1)   // 多行减税
                  || (gridValues.jsmxb.length == 1 && (item.qcyeMsxse + item.bqfseSjkce + item.bqsjdjseMsjxse != 0)    // 单行减税，并且填了第1、2或4栏
                  ))
                  && item.jmxzDm.length < 1) {    // 性质代码未选
                  addError("减免税申报明细表 一、减税项目 第" + (i + 2) + "栏_减税性质代码及名称  不能为空！");
                } else {
                  // 减税性质代码及名称不能重复
                  var indexStr = "";
                  var indexCount = 0;
                  for (var j = 0; j < gridValues.jsmxb.length; j++) {
                    if (gridValues.jsmxb[j].jmxzDm == item.jmxzDm) {
                      indexStr += (indexStr.length < 1 ? "" : "、") + String(j + 2);
                      indexCount++;
                    }
                  }
                  if (indexCount >= 2) {
                    addError("减免税申报明细表 一、减税项目 第" + indexStr + "栏_减税性质代码及名称  不能重复！");
                    break;
                  }
                }

                // 减税项目-第4栏应<=减税项目-第3栏
                if (item.bqsjdjseMsjxse > item.bqydjseKchmsxse) {
                  addError("减免税申报明细表 一、减税项目 第" + (i + 2) + "栏   第4列_本期实际抵减税额 应小于等于  第3列_本期应抵减税额！");
                }
              }

              // 主表第18行_本期数等于本表"一、减税项目"第4列_第1行，校验写在本表减税项目的第4列的合计上
              var realCount = 0;
              for (var i = 0; i < gridValues.jsmxb.length; i++) {
                realCount += gridValues.jsmxb[i].bqsjdjseMsjxse;
              }
              realCount = tools.parseValue(realCount, "float2");
              if (tools.parseValue(getValue("bys", 18) + getValue("bysFw", 18), "float2") != realCount) {
                addError("主表第18行_本期数[" + getValue("bys", 18) + " + " + getValue("bysFw", 18) + " = " + (tools.parseValue(getValue("bys", 18) + getValue("bysFw", 18), "float2")) + "]应等于  减免税申报明细表 一、减税项目-第1栏 第4列_本期实际抵减税额_合计[" + realCount + "]！");
              }
            }

            // 免税校验
            // 主表第12行“本期数”无数据时，不需填写本表的“二、免税项目”，校验写在本表免税项目的第1列的合计上
            if (tools.parseValue(getValue("bys", 12) + getValue("bysFw", 12), "float2") <= 0) {
              if (gridValues.msmxb.length > 1
                || ((gridValues.msmxb.length == 1 && (gridValues.msmxb[0].qcyeMsxse + gridValues.msmxb[0].bqfseSjkce + gridValues.msmxb[0].qmyeMse != 0 || gridValues.msmxb[0].jmxzDm.length > 0)))) {
                addError("主表第12行_本期数[" + getValue("bys", 12) + " + " + getValue("bysFw", 12) + " = " + (tools.parseValue(getValue("bys", 12) + getValue("bysFw", 12), "float2")) + "]等于0时，不应填写  减免税申报明细表“二、免税项目”！")
              }
            }

            if (gridValues.msmxb.length > 0) {
              for (var i = 0; i < gridValues.msmxb.length; i++) {
                var item = gridValues.msmxb[i];
                var line = gridValues.jsmxb.length + 5 + i;

                if ((
                  (gridValues.msmxb.length > 1)   // 多行免税
                  || (gridValues.msmxb.length == 1 && (item.qcyeMsxse + item.bqfseSjkce + item.qmyeMse > 0)    // 单行免税，并且填了第1、2或5栏
                  ))
                  && item.jmxzDm.length < 1) {    // 性质代码未选
                  addError("减免税申报明细表 二、免税项目 第" + line + "栏_免税性质代码及名称  不能为空！");
                } else {
                  // 免税性质代码及名称不能重复
                  var indexStr = "";
                  var indexCount = 0;
                  for (var j = 0; j < gridValues.msmxb.length; j++) {
                    if (gridValues.msmxb[j].jmxzDm == item.jmxzDm) {
                      indexStr += (indexStr.length < 1 ? "" : "、") + String(j + gridValues.jsmxb.length + 5);
                      indexCount++;
                    }
                  }
                  if (indexCount >= 2) {
                    addError("减免税申报明细表 二、免税项目 第" + indexStr + "栏_免税性质代码及名称  不能重复！");
                    break;
                  }
                }

                // 免税项目-第4栏应<=免税项目-第3栏
                if (item.bqsjdjseMsjxse > item.bqydjseKchmsxse) {
                  addError("减免税申报明细表 一、免税项目 第" + line + "栏   第4列_免税销售额对应的进项税额 应小于等于  第3列_扣除后免税销售额！");
                }

                // 免税项目-第5栏应>=0
                if (item.qmyeMse < 0) {
                  addError("减免税申报明细表 二、免税项目 第" + line + "栏   第5列_免税额 应大于等于0！");
                }
              }

              var realCount = 0;
              for (var i = 0; i < gridValues.msmxb.length; i++) {
                realCount += gridValues.msmxb[i].qcyeMsxse;
              }
              realCount = tools.parseValue(realCount, "float2");
              // 主表第12行本期数等于本表"二、免税项目"第1列"免征增值税项目销售额"第1行"合计"，校验写在本表免税项目第1列的合计上
              if (tools.parseValue(getValue("bys", 12) + getValue("bysFw", 12), "float2") != realCount) {
                addError("主表第12行_本期数[" + getValue("bys", 12) + " + " + getValue("bysFw", 12) + " = " + (tools.parseValue(getValue("bys", 12) + getValue("bysFw", 12), "float2")) + "]应等于  减免税申报明细表 二、免税项目  第" + (gridValues.jsmxb.length + 2) + "栏 第1列_免征增值税项目销售额_合计[" + realCount + "]！");
              }
            }
          }

          // 有地税
          // 有附加税且附加税未申报
          if (type.indexOf("fjs") >= 0 && nsrInfo.fjs != undefined && nsrInfo.fjs.fjsYsbBz != "Y" && nsrInfo.fjs.items != undefined) {
            if (gridValues.fjsJc.djlx == undefined || gridValues.fjsJc.djlx.length < 1) {
              addError("附加税费 纳税人信息  请选择登记类型！");
            }
            if (gridValues.fjsJc.sfzjlx == undefined || gridValues.fjsJc.sfzjlx.length < 1) {
              addError("附加税费 纳税人信息  请选择身份证件类型！");
            }
            if (gridValues.fjsJc.zjhm == undefined || gridValues.fjsJc.zjhm.length < 1) {
              addError("附加税费 纳税人信息  身份证件号码不能为空！");
            }
            if (gridValues.fjsJc.lxfs == undefined || gridValues.fjsJc.lxfs.length < 1) {
              addError("附加税费 纳税人信息  联系方式不能为空！");
            }

            var seHj = 0;
            // 第5列合计数应≥《增值税纳税申报表(适用于一般纳税人)》应补退税额、《增值税纳税申报表（适用于小规模）》应补退税额和《原油天然气增值税申报表》应补退税额的合计数。
            // 当《增值税纳税申报表(适用于一般纳税人)》应补退税额、《增值税纳税申报表（适用于小规模）》应补退税额或《原油天然气增值税申报表》应补退税额＜0时，按零计算。
            for (var i = 0; i < gridValues.fjs.length; i++) {
              var item = gridValues.fjs[i];
              if ("Y" == nsrInfo.gzbz) {
                seHj += item.bqybtse;
              }

              if (item.bqynsfe < item.jme) {
                addError("附加税费 " + item.zsxmMc + " 第7列“减免额(" + item.jme + ")”不应该大于“本期应纳税额(" + item.bqynsfe + ")”！");
              }
              if (!item.mz) {
                if (item.jmxzDm.length > 0 && item.jme <= 0) {
                  addError("附加税费 " + item.zsxmMc + " 第6列“减免性质代码”不为空时，第7列“减免额(" + item.jme + ")”应大于0！");
                } else if (item.jme > 0 && item.jmxzDm.length < 1) {
                  addError("附加税费 " + item.zsxmMc + " 第7列“减免额(" + item.jme + ")”大于0时，第6列“减免性质代码”不能为空！");
                } else if (item.jmxzDm.length < 1 && item.jme < 0) {
                  addError("附加税费 " + item.zsxmMc + " 第6列“减免性质代码”为空时，第7列“减免额(" + item.jme + ")”必须等于0！");
                }
              }
            }

            // 更正已缴款时不允许出现退税
            if ("Y" == nsrInfo.gzbz && "Y" == gridValues.fjsJc.sfjkBz && seHj < gridValues.fjsJc.yjkje) {
              addError("对已缴款的附加税费进行更正申报时，第11列应补(退)税(费)额合计(" + seHj + ")不能小于更正前已缴款金额(" + gridValues.fjsJc.yjkje + ") ");
            }
          }

          // 有个税且个税未申报
          if (type.indexOf("gs") >= 0 && nsrInfo.grsds != undefined && nsrInfo.grsds.ysbBz != "Y") {
          }
        })();
        // 提示校验
        (function () {
          var addWarning = function (errorMessage) {
            if (validateSign != VALIDATE_SIGN.error) {
              validateSign = VALIDATE_SIGN.warning;
            }
            message.push("（提示校验）" + errorMessage);
          };

          if (type.indexOf("zzs") >= 0) {
            // 有增值税
            var isXw2019 = false;
            var bdcError = false;
            var bqxseHj = 0;
            if (nsrInfo.is2019s) {
              // 2019新小微标准：不是逾期未认定，且实际销售额-不动产销售额 <= 起征点
              isXw2019 = nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y" && (calculateSrzeReal(nsrInfo, gridValues).value - gridValues.bysFw.bdcxse <= nsrInfo.zzs.qzd);
              if (gridValues.bysFw.bdcxse > bqxseHj) {
                // 不动产销售额 > 本期合计
                bdcError = true;
              }
            }

            if (nsrInfo.zzs.szlbDm != "02") {
              // 应税货物及劳务校验
              // 小微标准
              // 1）非逾期未认定企业
              // 2）第1、7、9、13栏次的“货物及劳务”列 “本期数”合计金额小于等于“小规模企业应税货物起征点”
              var __cache__ = "bys";
              var isXwqy = nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y" && // 非逾期未认定
                (getValue(__cache__, 1) + getValue(__cache__, 7) + getValue(__cache__, 9) + getValue(__cache__, 13) <= nsrInfo.zzs.qzd);
              if (nsrInfo.is2019s) {
                isXwqy = isXw2019;
              }

              /*
                             1、第1、2、3栏
                             条件：无
                             校验：第1行“应征增值税不含税销售额（3%征收率）”的“本期数”“货物及劳务”列≥2行“税务机关代开的增值税专用发票不含税销售额”、
                             3行“税控器具开具的普通发票不含税销售额”的“本期数”“货物及劳务”列之和（客户端提示）
                             */
//                            if (getValue(__cache__, 1) < getValue(__cache__, 2) + getValue(__cache__, 3)) {
//                                addWarning("“" + alias.bys[1].label + "”应该大于等于“" + alias.bys[2].label + "”、“" + alias.bys[3].label + "”之和！");
//                            }
              if (!bdcError) {
                var xw201911 = false;
                /*
                                 2、第1、2、3、7、8栏：
                                 条件：如果纳税人满足小微企业
                                 校验：主表第1栏等于第2栏,且第3、7、8栏为0。不符则给出提示信息
                                 “自2014年10月1日至2020年12月31日。若您月销售额小于等于3万元（季度销售额小于等于9万元），您可享受小微企业免征增值税政策。
                                 第1栏等于第2栏,且第3、7、8栏为0。请您重新核实确认。” （客户端提示，接收端强制）
                                 */
                if (isXwqy) {
                  if (getValue(__cache__, 1) == getValue(__cache__, 2) && getValue(__cache__, 3) == 0 && getValue(__cache__, 7) == 0 && getValue(__cache__, 8) == 0) {

                  } else {
                    if (nsrInfo.is2019s) {
                      if (bqxseHj - gridValues.bysFw.bdcxse > gridValues.bys.msWdqzdXse + gridValues.bysFw.msWdqzdXse) {
                        // 属于小微，扣除不动产销售额没有都填在11栏
                        addWarning("自2019年1月1日起，若您月销售额(扣除不动产销售额)小于等于10万元（季度销售额小于等于30万元），非不动产销售额部分(不包括开具或代开专用发票销售额)可享受小微企业免征增值税政策，请填写在第11栏“未达起征点销售额”。");
                        xw201911 = true;
                      }
                    } else {
                      addWarning("自2014年10月1日至2020年12月31日。若您月销售额小于等于3万元（季度销售额小于等于9万元），您可享受小微企业免征增值税政策。“" + alias.bys[1].label + "”等于“" + alias.bys[2].label + "”,且“" + alias.bys[3].label + "”、“" + alias.bys[7].label + "”、“" + alias.bys[8].label + "”为0。请您重新核实确认。");
                    }
                  }
                }
                /*
                                 3、第9栏
                                 条件：纳税人满足小微企业，第9栏在不等于0的情况下，第9栏等于第1栏等于第2栏
                                 提示：则提示信息 “请您将代开增值税专用发票以外的销售额填入相应免税栏次”。（客户端提示）
                                 */
                if (isXwqy && getValue(__cache__, 9) != 0 && getValue(__cache__, 9) == getValue(__cache__, 1) && getValue(__cache__, 9) == getValue(__cache__, 2)) {
                  addWarning("请您将代开增值税专用发票以外的销售额填入相应免税栏次！");
                }

                /*
                                 第11栏
                                 （2）
                                 条件：纳税人满足小微企业， 并且“纳税人类型代码”等于“个体工商户”
                                 校验：您属于小微企业，第11栏本期数不应为零，全部销售额仅为"税务机关代开的增值税专用发票不含税销售额"和"出口免税销售额"的除外!! （客户端提示）
                                 */
                if (!xw201911 && isXwqy && getValue(__cache__, 11) == 0) {
                  addWarning("当前企业属于小微企业，“" + alias.bys[11].label + "”不应为0，全部销售额仅为“税务机关代开的增值税专用发票不含税销售额”和“出口免税销售额”的除外！");
                }
              }
            }

            if (nsrInfo.zzs.szlbDm != "01") {
              // 服务、不动产和无形资产校验
              // 小微标准
              // （1）本列4、5、6栏全部为0时，无需申报附列资料的企业，主表第1、9、13栏次的“服务、不动产和无形资产”列 “本期数”合计金额小于等于“小规模企业应税服物起征点”
              // （3）非逾期未认定企业
              var __cache__ = "bysFw";
              var isXwqy = nsrInfo.zzs.yqwrdybrBz.toUpperCase() != "Y" && // 非逾期未认定
                (getValue(__cache__, 1) + getValue(__cache__, 9) + getValue(__cache__, 13) <= nsrInfo.zzs.fwqzd) && // 1, 9, 13 未达起征点
                (getValue(__cache__, 4) == 0 && getValue(__cache__, 5) == 0 && getValue(__cache__, 6) == 0);
              if (nsrInfo.is2019s) {
                isXwqy = isXw2019;
              }
              var isOther = getValue(__cache__, 4) != 0 || getValue(__cache__, 5) != 0 || getValue(__cache__, 6) != 0;

              /*
                             1、第1、2、3栏
                             条件：无
                             校验：一般情况下，“第1行_本期数_服务、不动产和无形资产”应≥“第2行_本期数_服务、不动产和无形资产”＋“第3行_本期数_服务、不动产和无形资产”!!（客户端提示）
                             */
//                            if (getValue(__cache__, 1) < getValue(__cache__, 2) + getValue(__cache__, 3)) {
//                                addWarning("一般情况下，“" + alias.bysFw[1].label + "”应该大于等于“" + alias.bysFw[2].label + "”、“" + alias.bysFw[3].label + "”之和！");
//                            }

              var xw201911 = false;
              if (!bdcError) {
                /*
                                 2、第1、2、3、7、8栏：
                                 条件：纳税人满足小微企业
                                 校验：主表第1栏等于第2栏,且第3、7、8栏为0。
                                 不符则给出提示信息“自2014年10月1日至2020年12月31日。若您月销售额小于等于3万元（季度销售额小于等于9万元），您可享受小微企业免征增值税政策。
                                 第1栏等于第2栏,且第3、7、8栏为0。请您重新核实确认。” （客户端提示，接收端强制）
                                 */
                if (isXwqy && !isOther) {
                  if (getValue(__cache__, 1) == getValue(__cache__, 2) && getValue(__cache__, 3) == 0 && getValue(__cache__, 7) == 0 && getValue(__cache__, 8) == 0) {

                  } else {
                    if (nsrInfo.is2019s) {
                      if (bqxseHj - gridValues.bysFw.bdcxse > gridValues.bys.msWdqzdXse + gridValues.bysFw.msWdqzdXse) {
                        // 属于小微，扣除不动产销售额没有都填在11栏
                        addWarning("自2019年1月1日起，若您月销售额(扣除不动产销售额)小于等于10万元（季度销售额小于等于30万元），非不动产销售额部分(不包括开具或代开专用发票销售额)可享受小微企业免征增值税政策，请填写在第11栏“未达起征点销售额”");
                        xw201911 = true;
                      }
                    } else {
                      addWarning("自2014年10月1日至2020年12月31日。若您月销售额小于等于3万元（季度销售额小于等于9万元），您可享受小微企业免征增值税政策。“" + alias.bysFw[1].label + "”等于“" + alias.bysFw[2].label + "”,且“" + alias.bysFw[3].label + "”、“" + alias.bysFw[7].label + "”、“" + alias.bysFw[8].label + "”为0。请您重新核实确认。");
                    }
                  }
                }
              }
              /*
                             3、第4、5、6栏
                             条件：无
                             校验：一般情况下，《增值税小规模主表》“第4行_本期数_服务、不动产和无形资产”应≥“第5行_本期数_服务、不动产和无形资产”＋“第6行_本期数_服务、不动产和无形资产”!!（客户端提示）
                             */
//                            if (getValue(__cache__, 4) < getValue(__cache__, 5) + getValue(__cache__, 6)) {
//                                addWarning("一般情况下，“" + alias.bysFw[4].label + "”应该大于等于“" + alias.bysFw[5].label + "”、“" + alias.bysFw[6].label + "”之和！");
//                            }
              /*
                             4、第4、5、6栏
                             条件：主表第4栏或第5栏或第6栏不为0
                             提示：第2列_4、5、6栏填写适用5%征收率的不含税销售额。有扣除项目的纳税人，本栏填写扣除后的不含税销售额。
                             如果您属于小微企业，请将除销售不动产外的适用5%的销售额，填列小微企业免税栏次!! （客户端提示校验）
                             */
              if (getValue(__cache__, 4) != 0 || getValue(__cache__, 5) != 0 || getValue(__cache__, 6) != 0) {
                addWarning("“" + alias.bysFw[4].label + "”、“" + alias.bysFw[5].label + "”、“" + alias.bysFw[6].label + "”填写适用5%征收率的不含税销售额。有扣除项目的纳税人，本栏填写扣除后的不含税销售额。如果您属于小微企业，请将除销售不动产外的适用5%的销售额，填写在小微企业免税栏次！");
              }
              /*
                             5、第4、5、6栏
                             条件：主表第4栏或第5栏或第6栏不为0，且按照小微规则计算数据≤计税依据时
                             提示：您可能属于小微企业，请确认填写准确后再进行申报（客户端提示）
                             */
              if ((getValue(__cache__, 1) + getValue(__cache__, 9) + getValue(__cache__, 13) <= nsrInfo.zzs.fwqzd) && (getValue(__cache__, 4) != 0 || getValue(__cache__, 5) != 0 || getValue(__cache__, 6) != 0)) {
                addWarning("您可能属于小微企业，请确认填写准确后再进行申报！");
              }

              if (!bdcError) {
                /*
                                 6、第9栏
                                 条件：纳税人满足小微企业，第9栏在不等于0的情况下，第9栏等于第1栏等于第2栏
                                 提示：则提示信息 “请您将代开增值税专用发票以外的销售额填入相应免税栏次”。（客户端提示）
                                 */
                if (isXwqy && !isOther) {
                  if (getValue(__cache__, 9) != 0 && (getValue(__cache__, 9) == getValue(__cache__, 1) && getValue(__cache__, 9) == getValue(__cache__, 2))) {
                    addWarning("请您将代开增值税专用发票以外的销售额填入相应免税栏次！");
                  }
                }

                /*
                                 第11栏
                                 （2）
                                 条件：纳税人满足小微企业， 并且“纳税人类型代码”等于“个体工商户”
                                 校验： 您属于小微企业，第11栏本期数不应为零，全部销售额仅为"税务机关代开的增值税专用发票不含税销售额"和"出口免税销售额"的除外!! （客户端提示）
                                 */
                if (!xw201911 && !isOther && isXwqy && getValue(__cache__, 11) == 0) {
                  if (nsrInfo.is2019s && gridValues.bys.msWdqzdXse + gridValues.bysFw.msWdqzdXse > 0) {
                    // 2019，且11栏只有有一行有数
                  } else {
                    addWarning("当前企业属于小微企业，“" + alias.bysFw[11].label + "”不应为0，全部销售额仅为“税务机关代开的增值税专用发票不含税销售额”和“出口免税销售额”的除外！");
                  }
                }
              }
            }
          }

          // 有地税
          // 有附加税且附加税未申报
          if (type.indexOf("fjs") >= 0 && nsrInfo.fjs != undefined && nsrInfo.fjs.fjsYsbBz != "Y" && nsrInfo.fjs.items != undefined) {
            var existed = false;
            if ("Y" != nsrInfo.zzs.ysbBz || ("Y" == nsrInfo.gzbz && "Y" == nsrInfo.zzs.zzsGzbz)) {
              // 正常申报或者更正时有增值税，才做此校验
              var ybtSeBq = tools.parseValue(Math.max(tools.parseValue(nsrInfo.zzs.xgmYbtse, "float2") + gridValues.bys.ybtSeBq + gridValues.bysFw.ybtSeBq, 0), "float2");
              var str = "";
              for (var i = 0; i < gridValues.fjs.length; i++) {
                var item = gridValues.fjs[i];
                if (ybtSeBq != item.ybzzs) {
                  existed = true;
                  str += (str.length < 1 ? "" : "、") + item.zsxmMc + ":" + item.ybzzs;
                }
              }
            }
            if (existed) {
              addWarning("附加税费  第1列“一般增值税(" + str + ")”不等于 增值税第24行(货物及劳务 + 服务、不动产和无形资产)合计（" + ybtSeBq + "）!");
            }
          }

          if (type.indexOf("gs") >= 0 && nsrInfo.grsds != undefined && nsrInfo.grsds.ysbBz != "Y") {

          }
        })();

        if (callBackName != undefined) {
          if (typeof callBackName == "function") {
            callBackName(validateSign, message.join("|"));
          } else {
            (new Function(callBackName + "(" + validateSign + ", \"" + message.join("|") + "\");"))()
          }
        } else {
          if (window.webkit) {
            window.webkit.messageHandlers.iosValidateCallback.postMessage([validateSign, message.join("|")]);
          }
        }
      }
    };
  };

  var tableInfo = null;
  /**
   * 初始化录入页面
   * @param _nsrInfo JSON字符串 通过申报接口返回的企业基本信息，需要添加nsrsbh
   * @param _defaultValue JSON字符串  原生应用部分保存的申报缓存数据，和申报接口报文格式一致
   */
  window.loadTable = function (_nsrInfo, _defaultValue, platform) {
    tableInfo = __init__(_nsrInfo, _defaultValue, platform);
  };

  /**
   * 获取所有的缓存数据
   *
   * @param callBackName Android回调函数名称，需要接收一个参数，参数为JSON字符串结构的缓存数据，和申报报文数据一致
   *                     (serviceName、nsrsbh、sssqQ、sssqZ四个节点如果在初始化时传入了，则一并返回，否则不包括）
   */
  window.talbeAllValues = function (callBackName) {
    if (tableInfo) {
      tableInfo.getValues(callBackName);
    }
  };

  /**
   * 获取简易申报报表数据及格式
   * @param callBackName  Android回调方法
   */
  window.getEasyTableValues = function (callBackName) {
    if (tableInfo) {
      tableInfo.inputEasy("getEasyTableValues", 0, 0, 0, callBackName);
    }
  };

  /**
   * 进行数据校验
   *
   * @param type         税种（zzs, gs, fjs）
   * @param tzzSh        投资人税号
   * @param callBackName Android回调函数名称，需要接收2个参数，
   *                     第一个参数为校验结果，0：表示通过校验，1：表示有提示性校验未通过，2：表示有强制校验未通过
   *                     第二个参数为字符串，用来描述错误信息，如果有多条错误，则使用 “|”进行分割
   */
  window.validate = function (type, callBackName) {
    if (tableInfo) {
      tableInfo.validate(type, callBackName);
    }
  };

  /**
   * 简易申报外部输入
   * @param type      税种
   * @param index     栏次/key
   * @param value     值
   * @param valueEx   增值税服务列的值/证件类型名称
   * @param callBackName Android回调函数名称
   */
  window.inputEasy = function (type, index, value, valueEx, callBackName) {
    if (tableInfo) {
      tableInfo.inputEasy(type, index, value, valueEx, callBackName);
    }
  };

  /**
   * 单个税种申报成功刷新页面
   * @param type         税种（zzs, gs, fjs）
   */
  window.loadSuc = function (type) {
    if (tableInfo) {
      tableInfo.loadSuc(type);
    }
  };

  /**
   * 写入不动产销售额
   * @param bdcxse        不动产销售额
   */
  window.inputBdcxse = function (bdcxse) {
    if (tableInfo) {
      tableInfo.inputBdcxse(bdcxse);
    }
  };

  window.setSelectedOption = function (value) {
    setTimeout(function () {
      var select = document.getElementById("sbb");
      for (var i = 0; i < select.options.length; i++) {
        var opt = select.options[i];
        if (value === opt.value) {
          opt.selected = true;
        }
      }
    }, 400);
  };

  // 显示报表
  window.showBb = function (bb) {
    if (bb == 'zzs') {
      // 显示增值税报表
      document.getElementById("zzs_zb").style.display = "block";
      setSelectedOption("zzs");
      document.getElementById("zzs_fb").style.display = "none";
      document.getElementById("fjs_zb").style.display = "none";
      document.getElementById("gs_zb").style.display = "none";

      document.getElementById("work_content").style.width = WIDTH_CONTENT_S + "px";
      document.getElementById("zzs_zb").style.width = (WIDTH_CONTENT_S - 10) + "px";
    } else if (bb == 'zzs_fb') {
      // 显示增值税附表
      document.getElementById("zzs_fb").style.display = "block";
      setSelectedOption("zzs_jm");
      document.getElementById("zzs_zb").style.display = "none";
      document.getElementById("fjs_zb").style.display = "none";
      document.getElementById("gs_zb").style.display = "none";

      document.getElementById("work_content").style.width = WIDTH_CONTENT_M + "px";
      document.getElementById("zzs_fb").style.width = (WIDTH_CONTENT_M - 10) + "px";
    } else if (bb == 'fjs') {
      // 显示附加税报表
      document.getElementById("fjs_zb").style.display = "block";
      setSelectedOption("fjs");
      document.getElementById("zzs_zb").style.display = "none";
      document.getElementById("zzs_fb").style.display = "none";
      document.getElementById("gs_zb").style.display = "none";

      document.getElementById("work_content").style.width = WIDTH_CONTENT_M + "px";
      document.getElementById("fjs_zb").style.width = (WIDTH_CONTENT_M - 10) + "px";
    } else if (bb == 'gs') {
      // 显示个税报表
      document.getElementById("gs_zb").style.display = "block";
      setSelectedOption("gs");
      document.getElementById("zzs_zb").style.display = "none";
      document.getElementById("zzs_fb").style.display = "none";
      document.getElementById("fjs_zb").style.display = "none";

      document.getElementById("work_content").style.width = WIDTH_CONTENT_S + "px";
      document.getElementById("gs_zb").style.width = (WIDTH_CONTENT_S - 10) + "px";
    }
  };

  // 计算销售额
  window.calculateSrze = function (nsrInfo, gridValues, haveGs) {
    // 实际收入
    var bysCount = tools.parseValue(gridValues.bys.yzBhsXse + gridValues.bys.yzBhsXse5 + gridValues.bys.ysgzBhsXse + gridValues.bys.msXse + gridValues.bys.ckmsXse, "float2");
    var bysFwCount = tools.parseValue(gridValues.bysFw.yzBhsXse + gridValues.bysFw.yzBhsXse5 + gridValues.bysFw.ysgzBhsXse + gridValues.bysFw.msXse + gridValues.bysFw.ckmsXse, "float2");

    // 货物最终收入
    var hwMax = Math.max(tools.parseValue(bysCount + tools.parseValue(nsrInfo.zzs.xgmXseHw, "float2"), "float2"), tools.parseValue(gridValues.bys.hdxse, "float2"));
    // 服务最终收入
    var fwMax = Math.max(tools.parseValue(bysFwCount + tools.parseValue(nsrInfo.zzs.xgmXseFw, "float2"), "float2"), tools.parseValue(gridValues.bysFw.hdxse, "float2"));

    if (haveGs) {
      return tools.parseValue(Math.max(tools.parseValue(hwMax + fwMax, "float2"), tools.parseValue(gridValues.grsds.hdsrze, "float2")), "float2");
    } else {
      return tools.parseValue(hwMax + fwMax, "float2");
    }
  };
  // 计算实际销售额
  window.calculateSrzeReal = function (nsrInfo, gridValues) {
    // 实际收入
    var bysCount = tools.parseValue(gridValues.bys.yzBhsXse + gridValues.bys.yzBhsXse5 + gridValues.bys.ysgzBhsXse + gridValues.bys.msXse + gridValues.bys.ckmsXse, "float2");
    var bysFwCount = tools.parseValue(gridValues.bysFw.yzBhsXse + gridValues.bysFw.yzBhsXse5 + gridValues.bysFw.ysgzBhsXse + gridValues.bysFw.msXse + gridValues.bysFw.ckmsXse, "float2");

    // 货物最终收入
    var hwMax = tools.parseValue(bysCount + tools.parseValue(nsrInfo.zzs.xgmXseHw, "float2"), "float2");
    // 服务最终收入
    var fwMax = tools.parseValue(bysFwCount + tools.parseValue(nsrInfo.zzs.xgmXseFw, "float2"), "float2");

    return {
      value: tools.parseValue(hwMax + fwMax, "float2"),
      hw: hwMax,
      fw: fwMax
    };
  };
  // 判断产教融合是否全额抵免
  window.isCjrhAlljz = function (gridValues) {
    var sum = 0;
    for (var i = 0; i < gridValues.fjs.length; i++) {
      var item = gridValues.fjs[i];
      if (item.zsxmDm == "30203" || item.zsxmDm == "30216") {
        sum += Math.max(item.bqynsfe - item.jme - item.phjmse, 0);
      }
    }

    return sum <= tools.parseValue(gridValues.fjsJc.dqxztze * gridValues.fjsJc.jzbl + gridValues.fjsJc.sqldkdmje, "float2");
  };
  window.whasZzs = function (nsr) {
    return nsr.zzs.ysbBz != 'Y' || (!whasFjs(nsr) && !whasGs(nsr));
  };
  window.whasFjs = function (nsr) {
    return nsr.fjs != undefined && nsr.fjs.fjsYsbBz != 'Y' && nsr.fjs.items != undefined;
  };
  window.whasGs = function (nsr) {
    return nsr.grsds != undefined && nsr.grsds.ysbBz != 'Y';
  };
})
();