(function () {
    "use strict";

    var WIDTH_CONTENT_M = 940;

    var DEFAULT_NSR_INFO = {
        "returnCode": "00",
        "returnMessage": "",
        "gzbz": "N",
        "yhs": {
            "zzsXgmBz": "",
            "ysbBz": "",
            "nsrsbh": "",
            "nsrmc": "",
            "sfzjlxDm": "",
            "sfzjlxMc": "",
            "zjhm": "",
            "sssqQ": "",
            "sssqZ": "",
            "nsrlx": "0",
            "lxdh": "",
            "zspm": []
        }
    };

    var DEFAULT_GRID_VALUES = {
        "serviceName": "",
        "nsrsbh": "",
        "zb": {
            "zbData": [],
            "sssqQ": "",
            "sssqZ": "",
            "nsrlx": "0",
            "sfzjhm": "",
            "sfzjlx": "",
            "lxdh": "",
            "bqsfsyxgmyhzc": "",
            "phjmxzDm": "",
            "phjmswsxDm": "",
            "phjzbl": 0,
            "phjzblDef": 0,
            "phjmse": 0,
            "hjseDef": 0,
            "hjse": 0
        }
    };

    var __init__ = function (_nsrInfo, _defaultValue) {
        if (typeof _nsrInfo == "string") {
            _nsrInfo = JSON.parse(_nsrInfo);
        }
        if (typeof _defaultValue == "string") {
            _defaultValue = JSON.parse(_defaultValue);
        }
        // 计算初始化数据，全部数据采用深度克隆和空对象继承的方式处理，方式在程序运行中对基础对象信息产生修改
        var nsrInfo = JSON.extend({}, DEFAULT_NSR_INFO, _nsrInfo); // 纳税人信息的克隆
        var gridValues = JSON.extend({}, DEFAULT_GRID_VALUES, _defaultValue); // 申报数据的克隆

        // 补充特殊信息
        var COLUMN_KEYS = [
            "",
            "jsje",
            "hdzsHdde",
            "hdzsHdbl",
            "sysl",
            "bqynse",
            "bqyjse1",
            "ssjmxzDm",
            "jmse",
            "phjmse",
            "bqybtse",
            "ssjmsxDm"
        ];

        //  初始化报表显示
        gridValues.nsrsbh = nsrInfo.nsrsbh;
        gridValues.zb.sssqQ = nsrInfo.yhs.sssqQ;
        gridValues.zb.sssqZ = nsrInfo.yhs.sssqZ;

        gridValues.zb.nsrlx = nsrInfo.yhs.nsrlx;
        gridValues.zb.sfzjhm = nsrInfo.yhs.sfzjhm;
        gridValues.zb.sfzjlx = nsrInfo.yhs.sfzjlxDm;
        gridValues.zb.lxdh = nsrInfo.yhs.lxdh;

        if ("Y" == nsrInfo.gzbz) {
            // 更正申报印花税
            gridValues.serviceName = "doGzSbYhs";
            gridValues.zb.pzxh = gridValues.yhsgz.pzxh;
            gridValues.zb.sbuuid = gridValues.yhsgz.sbuuid;

            if (gridValues.yhsgz != undefined) {
                var hjse = 0;
                for (var i = 0; i < nsrInfo.yhs.zspm.length; i++) {
                    var itemJc = nsrInfo.yhs.zspm[i];
                    var itemGz = gridValues.yhsgz.zspm[i];
                    if (itemGz != undefined) {
                        if (i == 0) {
                            gridValues.zb.bqsfsyxgmyhzc = itemGz.bqsfsyxgmyhzc;
                            gridValues.zb.phjzbl = gridValues.zb.bqsfsyxgmyhzc == "Y" ? 0.5 : 0;
                            gridValues.zb.phjzblDef = gridValues.zb.bqsfsyxgmyhzc == "Y" ? 0.5 : 0;
                        }
                        gridValues.zb.zbData.push({
                            "ewbhxh": i + 1,
                            "zspmDm": itemGz.zspmDm,
                            "zspmMc": itemJc.zspmMc,
                            "jsje": tools.parseValue(itemGz.jsje, "float2"),
                            "hdzsHdde": tools.parseValue(itemGz.hdzsHdde, "float2"),
                            "hdzsHdbl": tools.parseValue(itemGz.hdzsHdbl, "float2"),
                            "sysl": tools.parseValue(itemGz.sysl, "float6"),
                            "syslPer": tools.parseValue(itemGz.sysl * 100, "float4"),
                            "bqynse": tools.parseValue(itemGz.bqynse, "float2"),
                            "bqyjse1": tools.parseValue(itemGz.bqyjse1, "float2"),
                            "ssjmxzDm": itemGz.ssjmxzDm,
                            "ssjmsxDm": itemGz.ssjmsxDm,
                            "jmse": tools.parseValue(itemGz.jmse, "float2"),
                            "autoComputeJm": false,
                            "autoComputePhjmse": false,
                            "phjmse": tools.parseValue(itemGz.phjmse, "float2"),
                            "bqybtse": tools.parseValue(itemGz.bqybtse, "float2")
                        });
                        hjse += tools.parseValue(itemGz.bqybtse, "float2");
                    }
                }
                gridValues.zb.hjseDef = hjse;
            }
        } else {
            // 正常申报印花税
            gridValues.serviceName = "doSbYhs";

            gridValues.zb.bqsfsyxgmyhzc = nsrInfo.yhs.zzsXgmBz == "Y" ? "Y" : "N";
            gridValues.zb.phjzbl = gridValues.zb.bqsfsyxgmyhzc == "Y" ? 0.5 : 0;
            gridValues.zb.phjzblDef = gridValues.zb.bqsfsyxgmyhzc == "Y" ? 0.5 : 0;

            for (var i = 0; i < nsrInfo.yhs.zspm.length; i++) {
                var item = nsrInfo.yhs.zspm[i];
                gridValues.zb.zbData.push({
                    "ewbhxh": i + 1,
                    "zspmDm": item.zspmDm,
                    "zspmMc": item.zspmMc,
                    "jsje": 0,
                    "hdzsHdde": 0,
                    "hdzsHdbl": tools.parseValue(item.hdbl, "float2"),
                    "sysl": tools.parseValue(item.sl, "float6"),
                    "syslPer": tools.parseValue(item.sl * 100, "float4"),
                    "bqynse": 0,
                    "bqyjse1": 0,
                    "ssjmxzDm": "",
                    "ssjmsxDm": "",
                    "jmse": 0,
                    "autoComputeJm": true,
                    "autoComputePhjmse": true,
                    "phjmse": 0,
                    "bqybtse": 0
                });
            }
        }

        showBb();

        /**
         * 自动计算
         * @param row 自动计算的行次（row == -1时，所有行次进行计算，否则，指定行次计算）
         */
        var autoCompute = function (row) {
            for (var i = 0; i < gridValues.zb.zbData.length; i++) {
                var item = gridValues.zb.zbData[i];
                if (row == -1 || row == i) {
                    // 5 = 1*4+2*3*4
                    item[COLUMN_KEYS[5]] = tools.parseValue(item[COLUMN_KEYS[1]] * item[COLUMN_KEYS[4]] + item[COLUMN_KEYS[2]] * item[COLUMN_KEYS[3]] * item[COLUMN_KEYS[4]], "float2");

                    // 不影响减免额值计算的修改，不更新减免额
                    // 手动修改减免额、本期已缴税额时，不自动计算减免额
                    if (item[COLUMN_KEYS[5]] > 0 && item.autoComputeJm) {
                        // 101110501 资金账簿       自动带减免 0009129906
                        if (item.zspmDm == "101110501") {
                            item[COLUMN_KEYS[7]] = "0009129906";
                            // 8 = 5 * 50%
                            item[COLUMN_KEYS[8]] = tools.parseValue(item[COLUMN_KEYS[5]] / 2, "float2");
                        } else if (item.zspmDm == "101110599") {
                            // 101110599 其他营业账簿    自动带减免    0009129907
                            item[COLUMN_KEYS[7]] = "0009129907";
                            // 8 = 5 * 100%
                            item[COLUMN_KEYS[8]] = item[COLUMN_KEYS[5]];
                        }
                    }

                    // 手动修改了普惠减免，不自动计算
                    if (item.autoComputePhjmse) {
                        // 自动计算普惠减免额
                        // 9 = (5 - 8) * 减征比例
                        item[COLUMN_KEYS[9]] = tools.parseValue(Math.max(0, item[COLUMN_KEYS[5]] - item[COLUMN_KEYS[8]]) * gridValues.zb.phjzbl, "float2");
                        item.phjmseMax = item[COLUMN_KEYS[9]];
                    }

                    // 10 = 5-6-8-9 (10可以为负数)
                    item[COLUMN_KEYS[10]] = tools.parseValue(item[COLUMN_KEYS[5]] - item[COLUMN_KEYS[6]] - item[COLUMN_KEYS[8]] - item[COLUMN_KEYS[9]], "float2");

                    // 每次计算之后，默认需要自动计算减免额
                    item.autoComputeJm = true;
                    item.autoComputePhjmse = true;
                    if (row == i) {
                        return;
                    }
                }
            }
        };

        (function () {
            // 录入项目及类型
            var infos = [
                {name: COLUMN_KEYS[1], type: 'float2', title: "计税金额或件数", column: 1},
                {name: COLUMN_KEYS[2], type: 'float2', title: "核定依据", column: 2},
                {name: COLUMN_KEYS[6], type: 'float2', title: "本期已缴税额", column: 6},
                {name: COLUMN_KEYS[7], type: 'jmxzDm_yhs', title: "减免性质代码", column: 7},
                {name: COLUMN_KEYS[8], type: 'float2', title: "减免额", column: 8},
                {name: COLUMN_KEYS[9], type: 'float2', title: "增值税小规模纳税人减征额", column: 9}
            ];

            // 自动计算（自动减免）
            autoCompute(-1);

            /**
             * 印花税主表模版
             */
            var yhs_zb = new Vue({
                el: "#yhs_zb",
                data: {
                    nsr: nsrInfo,
                    gridData: gridValues
                },
                computed: {
                    countAll5: function () {
                        var sum = 0;
                        for (var i = 0; i < this.gridData.zb.zbData.length; i++) {
                            sum += this.gridData.zb.zbData[i].bqynse;
                        }
                        return tools.parseValue(sum, "float2");
                    },
                    countAll6: function () {
                        var sum = 0;
                        for (var i = 0; i < this.gridData.zb.zbData.length; i++) {
                            sum += this.gridData.zb.zbData[i].bqyjse1;
                        }
                        return tools.parseValue(sum, "float2");
                    },
                    countAll8: function () {
                        var sum = 0;
                        for (var i = 0; i < this.gridData.zb.zbData.length; i++) {
                            sum += this.gridData.zb.zbData[i].jmse;
                        }
                        return tools.parseValue(sum, "float2");
                    },
                    countAll9: function () {
                        var sum = 0;
                        for (var i = 0; i < this.gridData.zb.zbData.length; i++) {
                            sum += this.gridData.zb.zbData[i].phjmse;
                        }
                        this.gridData.zb.phjmse = tools.parseValue(sum, "float2");
                        return this.gridData.zb.phjmse;
                    },
                    countAll10: function () {
                        var sum = 0;
                        for (var i = 0; i < this.gridData.zb.zbData.length; i++) {
                            sum += this.gridData.zb.zbData[i].bqybtse;
                        }
                        this.gridData.zb.hjse = tools.parseValue(sum, "float2");
                        return this.gridData.zb.hjse;
                    }
                },
                methods: {
                    setRadioYhsJz: function (e) {
                        var jzbz = e.currentTarget.value;
                        this.gridData.zb.phjzbl = "Y" == jzbz ? this.gridData.zb.phjzblDef : 0;

                        // 修改是否使用小规模减征时，不自动计算减免额
                        for (var i = 0; i < this.gridData.zb.zbData.length; i++) {
                            var item = gridValues.zb.zbData[i];
                            item.autoComputeJm = false;
                        }
                        autoCompute(-1);
                    },
                    setValue: function (row, index) {
                        var notices = {
                            "name": infos[index].name,
                            "cache": "mx_" + row,
                            "label": this.gridData.zb.zbData[row].zspmMc + "、第" + infos[index].column + "列  " + infos[index].title,
                            "type": infos[index].type,
                            "index": row * 100 + index + 1
                        };
                        var item = this.gridData.zb.zbData[row];
                        var defautValue = item[notices.name];
                        if (notices.name == "ssjmxzDm") {
                            defautValue = item[notices.name] + "," + item.ssjmsxDm;
                        }
                        var value = prompt(JSON.stringify(notices), defautValue);
                        if (!!value) {
                            var __value__ = JSON.parse(value);
                            var inputValue = tools.parseValue(__value__.value, notices.type);
                            if (notices.name == "phjmse") {
                                // 修改普惠减免金额
                                if (inputValue > item.phjmseMax) {
                                    alert(item.zspmMc + " 第9列、增值税小规模纳税人减征额不能大于" + item.phjmseMax);
                                    return
                                }
                                item.autoComputePhjmse = false;
                            }
                            item[notices.name] = inputValue;

                            if (notices.name == "jmse" || notices.name == "bqyjse1") {
                                // 手动修改减免额、本期已缴税额时，不自动计算减免额
                                item.autoComputeJm = false;
                                if (notices.name == "bqyjse1") {
                                    item.autoComputePhjmse = false;
                                }
                            } else if (notices.name == "ssjmxzDm") {
                                item.ssjmxzDm = tools.parseValue(__value__.value, notices.type).split(",")[0];
                                item.ssjmsxDm = tools.parseValue(__value__.value, notices.type).split(",")[1];
                                // 修改减免性质代码
                                if (item.zspmDm == "101110501") {
                                    if (item.ssjmxzDm != "0009129906") {
                                        item.autoComputeJm = false;
                                    }
                                } else if (item.zspmDm == "101110599") {
                                    if (item.ssjmxzDm != "0009129907") {
                                        item.autoComputeJm = false;
                                    }
                                }
                            }
                            autoCompute(row);

                            var step = 0;
                            if ("1" == __value__.flag) {
                                step = -1;
                            } else if ("2" == __value__.flag) {
                                step = 1;
                            }
                            if (step != 0) {
                                var nextIndex = index + step;
                                if (nextIndex < 0) {
                                    nextIndex = infos.length - 1;
                                }
                                if (nextIndex >= infos.length) {
                                    nextIndex = 0;
                                }
                                this.setValue(row, nextIndex);
                            }
                        }
                    }
                }
            });
        })();
        return {
            getValues: function (callBackName) {
                gridValues.zb.phjmxzDm = gridValues.zb.bqsfsyxgmyhzc == "Y" ? "0009049901" : "";
                gridValues.zb.phjmswsxDm = gridValues.zb.bqsfsyxgmyhzc == "Y" ? "XA031900989" : "";

                // 适用税率获取时改为字符串格式
                for (var i = 0; i < gridValues.zb.zbData.length; i++) {
                    var item = gridValues.zb.zbData[i];
                    item.sysl = "" + item.sysl;
                }

                if ("Y" == nsrInfo.gzbz) {
                    // 更正税额变化标志
                    gridValues.zb.sbcwgzjs = gridValues.zb.hjse != gridValues.zb.hjseDef ? "Y" : "N";

                    // 清除yhsgz无用字段
                    gridValues.yhsgz = {};
                }

                var resultValues = JSON.stringify(gridValues);

                if (callBackName != undefined) {
                    if (typeof callBackName == "function") {
                        callBackName(resultValues);
                    } else {
                        (new Function(callBackName + " (JSON.stringify(" + resultValues + "));"))()
                    }
                } else {
                    window.webkit.messageHandlers.iosTalbeAllValuesCallback.postMessage(resultValues);
                }
            },
            loadSuc: function (type) {
                if ('yhs' == type && whasYhs(nsrInfo)) {
                    nsrInfo.yhs.ysbBz = "Y";
                }
            },
            validate: function (callBackName) {
                var VALIDATE_SIGN = {
                    "success": 0,
                    "error": 1,
                    "warning": 2
                };
                var validateSign = VALIDATE_SIGN.success;
                var message = [];
                var addError = function (errorMessage) {
                    validateSign = VALIDATE_SIGN.error;
                    message.push("（强制校验）" + errorMessage);
                };
                /**
                 * 约等于
                 *
                 * @param {Object} left 等式左边的值
                 * @param {Object} right 等式右边的值
                 * @param {Object} errorRange 误差范围
                 */
                var approximate = function (left, right, errorRange) {
                    var dValue = tools.parseValue(Math.abs(left - right), "float2");
                    var eRange = tools.parseValue(Math.abs(errorRange), "float2");
                    return dValue <= eRange;
                };
                // 2.2表内校验
                if (whasYhs(nsrInfo)) {
                    for (var i = 0; i < gridValues.zb.zbData.length; i++) {
                        var item = gridValues.zb.zbData[i];

                        if (item.jmse > item.bqynse) {
                            // 减免额应不能大于本期应纳税额
                            addError("印花税 " + item.zspmMc + " 第8列“减免额(" + item.jmse + ")”必须小于等于第5列“本期应纳税额”！");
                        }

                        if (item.ssjmxzDm.length > 0 && item.jmse <= 0) {
                            addError("印花税 " + item.zspmMc + " 第7列“减免性质代码”不为空时，第8列“减免额(" + item.jmse + ")”应大于0！");
                        } else if (item.jmse > 0 && item.ssjmxzDm.length < 1) {
                            addError("印花税 " + item.zspmMc + " 第8列“减免额(" + item.jmse + ")”大于0时，第7列“减免性质代码”不能为空！");
                        } else if (item.ssjmxzDm.length < 1 && item.jmse < 0) {
                            addError("印花税 " + item.zspmMc + " 第7列“减免性质代码”为空时，第8列“减免额(" + item.jmse + ")”必须等于0！");
                        }
                    }
                }

                if (callBackName != undefined) {
                    if (typeof callBackName == "function") {
                        callBackName(validateSign, message.join("|"));
                    } else {
                        (new Function(callBackName + "(" + validateSign + ", \"" + message.join("|") + "\");"))()
                    }
                } else {
                    window.webkit.messageHandlers.iosValidateCallback.postMessage([validateSign, message.join("|")]);
                }
            }
        };
    };

    var tableInfo = null;
    /**
     * 初始化录入页面
     * @param _nsrInfo JSON字符串 通过申报接口返回的企业基本信息，需要添加nsrsbh
     * @param _defaultValue JSON字符串  原生应用部分保存的申报缓存数据，和申报接口报文格式一致
     */
    window.loadTable = function (_nsrInfo, _defaultValue) {
        tableInfo = __init__(_nsrInfo, _defaultValue);
    };

    /**
     * 获取所有的缓存数据
     *
     * @param callBackName 回调函数名称，需要接收一个参数，参数为JSON字符串结构的缓存数据，和申报报文数据一致
     *                     (serviceName、nsrsbh、sssqQ、sssqZ四个节点如果在初始化时传入了，则一并返回，否则不包括）
     */
    window.talbeAllValues = function (callBackName) {
        if (tableInfo) {
            tableInfo.getValues(callBackName);
        }
    };

    /**
     * 进行数据校验
     *
     * @param callBackName 回调函数名称，需要接收2个参数，
     *                     第一个参数为校验结果，0：表示通过校验，1：表示有提示性校验未通过，2：表示有强制校验未通过
     *                     第二个参数为字符串，用来描述错误信息，如果有多条错误，则使用 “|”进行分割
     */
    window.validate = function (callBackName) {
        if (tableInfo) {
            tableInfo.validate(callBackName);
        }
    };

    /**
     * 单个税种申报成功刷新页面
     * @param type         税种（yhs）
     */
    window.loadSuc = function (type) {
        if (tableInfo) {
            tableInfo.loadSuc(type);
            tableInfo.loadSuc(type);
        }
    };

    // 是否印花税未申报
    window.whasYhs = function (nsrInfo) {
        return nsrInfo.yhs != undefined && nsrInfo.yhs.sssqQ != undefined && nsrInfo.yhs.sssqQ.length == 8 && nsrInfo.yhs.ysbBz != "Y";
    };
    // 显示报表
    window.showBb = function () {
        document.getElementById("work_content").style.width = WIDTH_CONTENT_M + "px";
        document.getElementById("yhs_zb").style.width = (WIDTH_CONTENT_M - 10) + "px";
    }
})();