"use strict";
var tools = (function () {
    /**
     * 格式化日期
     * @param date  日期
     * @param split 分隔符
     */
    var formatDate = function (date, split) {
        if (date == undefined) {
            date = new Date();
        }
        if (split == undefined) {
            split = "-";
        }
        var year = 1900 + date.getYear();

        var month = date.getMonth() + 1 + "";
        if (month.length == 1) {
            month = "0" + month;
        }

        var day = date.getDay() + "";
        if (day.length == 1) {
            day = "0" + day;
        }

        return year + split + month + split + day;
    };
    /**
     * 按照数据类型格式化数据
     * @param {Object} value
     * @param {Object} type
     */
    var parseValue = function (value, type) {
        if (value == undefined || value == "") {
            if (type == "int" || type == "float2" || type == "float4") {
                return 0;
            } else {
                return "";
            }
        }

        var __value__ = value;
        var needNumber = false;
        var fixed = 0;
        if ("int" == type) {
            needNumber = true;
            fixed = 0;
        } else if ("float2" == type) {
            needNumber = true;
            fixed = 2;
        } else if ("float4" == type) {
            needNumber = true;
            fixed = 4;
        } else if ("float6" == type) {
            needNumber = true;
            fixed = 6;
        }
        if (needNumber) {
            if (typeof __value__ != "number") {
                __value__ = parseFloat(__value__.toString(), 10);
            }
            if (isNaN(__value__)) {
                __value__ = 0;
            } else {
                var dividendTemp = Math.pow(10, fixed + 4);
                __value__ = Math.round(__value__ * dividendTemp) / dividendTemp;

                var dividend = Math.pow(10, fixed);
                __value__ = Math.round(__value__ * dividend) / dividend;
            }
            if (isNaN(__value__)) {
                __value__ = 0;
            }
        }
        return __value__;
    };
    /**
     * 数据对象深层克隆
     * 算法来源：http://www.cnblogs.com/birdshome/archive/2005/03/20/122246.html
     */
    var deepClone = function (source) {
        var objClone = null;
        if (source.constructor == Object) {
            objClone = new source.constructor();
        } else {
            objClone = new source.constructor(source.valueOf());
        }
        for (var key in source) {
            if (objClone[key] != source[key]) {
                if (typeof (source[key]) == 'object') {
                    objClone[key] = deepClone(source[key]);
                } else {
                    objClone[key] = source[key];
                }
            }
        }
        objClone.toString = source.toString;
        objClone.valueOf = source.valueOf;
        return objClone;
    };

    var sortBy = function (arr, aes) {
        if (aes == undefined) {
            aes = 1;
        } else {
            aes = aes ? 1 : -1;
        }
        return function (a, b) {
            a = a[arr];
            b = b[arr];
            if (a < b) {
                return aes * -1;
            }
            if (a > b) {
                return aes * 1;
            }
            return 0;
        }
    };
    return {
        formatDate: formatDate,
        parseValue: parseValue,
        deepClone: deepClone,
        sortBy: sortBy
    };
})();